OC.L10N.register(
    "spreed",
    {
    "a conversation" : "pokalbis",
    "(Duration %s)" : "(Trukmė %s)",
    "You attended a call with {user1}" : "Jūs dalyvavote skambutyje su {user1}",
    "_%n guest_::_%n guests_" : ["%n svečias","%n svečiai","%n svečių","%n svečias"],
    "You attended a call with {user1} and {user2}" : "Jūs dalyvavote skambutyje su {user1} ir {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Jūs dalyvavote skambutyje su {user1}, {user2} ir {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Jūs dalyvavote skambutyje su {user1}, {user2}, {user3} ir {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Jūs dalyvavote skambutyje su {user1}, {user2}, {user3}, {user4} ir {user5}",
    "_%n other_::_%n others_" : ["dar %n asmuo","dar %n asmenys","dar %n asmenų","dar %n asmuo"],
    "{actor} invited you to {call}" : "{actor} pakvietė jus į {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Jūs buvote pakviesti į <strong>pokalbį</strong> arba jums <strong>skambino</strong>",
    "Other activities" : "Kitos veiklos",
    "Talk" : "Pokalbiai",
    "Guest" : "Svečias",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## Sveiki atvykę į Nextcloud Pokalbius!\nŠiame pokalbyje būsite informuojami apie naujas Nextcloud Pokalbiuose prieinamas ypatybes.",
    "## New in Talk %s" : "## Nauja Pokalbiuose %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Dabar, dalyvavimui vaizdo ir garso skambučiuose gali būti naudojamos Microsoft Edge ir Safari naršyklės",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Dviejų asmenų pokalbiai dabar išlieka ir jų nebėra galima netyčia paversti grupiniais pokalbiais. Be to, jei vienas iš dalyvių išeina iš pokalbio, pokalbis nebėra automatiškai ištrinamas. Pokalbis iš serverio ištrinamas tik tada, kai abu dalyviai išeina.",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Galite siųsti pranešimą visiems dalyviams, pokalbyje parašę \"@all\"",
    "- With the \"arrow-up\" key you can repost your last message" : "- Naudodami klavišą \"rodyklė aukštyn\" galite iš naujo paskelbti savo paskutinę žinutę",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Nuo šiol, Pokalbiuose gali būti komandos. Siųskite pokalbyje žinutę \"/help\" norėdami pamatyti ar jūsų administratorius yra sukonfigūravęs kokias nors komandas",
    "- With projects you can create quick links between conversations, files and other items" : "- Naudodami projektus galite greitai sukurti sąsajas tarp pokalbių, failų bei kitų elementų",
    "- You can now mention guests in the chat" : "- Dabar, pokalbiuose galite minėti svečius",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Dabar, pokalbiuose yra laukiamasis. Tai leis moderatoriams prisijungti prie pokalbio ir skambinti, kad paruoštų susitikimą, kol tuo tarpu kiti naudotojai ir svečiai turės laukti",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Dabar, galite tiesiogiai atsakyti į žinutes, suteikdami kitiems vartotojams daugiau konteksto apie ką yra jūsų žinutė",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Dabar, pokalbių ir dalyvių paieška taip pat filtruos ir jūsų esamus pokalbius, todėl bus žymiai lengviau rasti ankstesnius pokalbius",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Nuo šiol, kai turite įdiegtą ratų programėlę, galite pridėti į pokalbius tinkintas vartotojų grupes",
    "- Check out the new grid and call view" : "- Susipažinkite su naujuoju tinkleliu ir skambučių peržiūros režimu",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Dabar galite įkelti failus ir juos perkelti tiesiai iš savo įrenginio į pokalbių langą",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Bendrai naudojami failai dabar atidaromi tiesiogiai pokalbių lange naudojant peržiūros programas",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Dabar viršutinėje juostoje esančioje bendrojoje paieškoje galite ieškoti pokalbių ir pranešimų",
    "- Spice up your messages with emojis from the emoji picker" : "- Praturtinkite savo žinutes emociukams iš emociukų parinkiklio",
    "- You can now change your camera and microphone while being in a call" : "- Dabar pokalbio metu galite pakeisti kamerą ir mikrofoną",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Pridėkite pokalbiams konteksto, pateikdami aprašymą, ir padarykite juos viešai prieinamus, kad prisijungę vartotojai galėtų juos rasti ir prisijungti",
    "- See a read status and send failed messages again" : "- Peržiūrėkite skaitymo būseną ir dar kartą siųskite nepavykusius pranešimus",
    "- Raise your hand in a call with the R key" : "- Pakelkite ranką skambučio metu naudodami R klavišą",
    "- Join the same conversation and call from multiple devices" : "- Prisijunkite prie to paties pokalbio ir skambinkite iš kelių įrenginių",
    "- Send voice messages, share your location or contact details" : "- Siųskite balso pranešimus, bendrinkite savo buvimo vietą arba kontaktinę informaciją",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Pridėkite grupes prie pokalbio ir nauji grupės nariai bus automatiškai pridėti kaip dalyviai",
    "- A preview of your audio and video is shown before joining a call" : "- Prieš prisijungiant prie skambučio rodoma jūsų garso ir vaizdo peržiūra",
    "- You can now blur your background in the newly designed call view" : "- Dabar naujai sukurtame skambučių rodinyje galite sulieti foną",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderatoriai dabar gali priskirti bendruosius ir individualius leidimus dalyviams",
    "- You can now react to chat messages" : "- Dabar galite reaguoti į pokalbių žinutes",
    "- In the sidebar you can now find an overview of the latest shared items" : "- Dabar šoninėje juostoje galite rasti paskutinių bendrintų elementų apžvalgą",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Pasinaudokite apklausos funkcija, kad surinktumėte kitų nuomones arba susitartumėte dėl datos",
    "- Configure an expiration time for chat messages" : "- Nustatyti pokalbių pranešimų galiojimo laiką",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Pradėkite pokalbius nepranešdami kitiems didelių pokalbių dalyviams. Pradėjus pokalbį, galite išsiųsti individualius pranešimus apie pokalbį.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Siųskite pokalbių pranešimus nepranešdami gavėjams, jei tai nėra skubu",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Dabar emociukus galima užbaigti automatiškai, įvedus simbolį „:“",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Susiekite įvairius elementus naudodami naująjį išmanųjį rinkiklį, įvesdami simbolį „/“",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Moderatoriai dabar gali kurti atskiras diskusijų patalpas (reikalingas didelio našumo serveris)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Dabar galima įrašyti skambučius (reikalingas našus serveris)",
    "- Conversations can now have an avatar or emoji as icon" : "- Pokalbių piktogramomis dabar gali būti avatarai arba emociukai",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Vaizdo skambučių metu dabar galima naudoti ne tik išblukintą foną, bet ir virtualius fonus",
    "- Reactions are now available during calls" : "- Dabar skambučių metu galima naudotis reakcijomis",
    "- Typing indicators show which users are currently typing a message" : "- Rašymo indikatoriai rodo, kurie vartotojai šiuo metu rašo žinutę",
    "- Groups can now be mentioned in chats" : "- Dabar pokalbiuose galima paminėti grupes",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Pokalbių įrašai automatiškai transkribuojami, jei yra užregistruota transkribavimo paslaugų teikėjo programa",
    "- Chat messages can be translated if a translation provider app is registered" : "- Pokalbių pranešimus galima išversti, jei yra įdiegta vertimo paslaugų teikėjo programėlė",
    "- **Markdown** can now be used in _chat_ messages" : "- **Markdown** dabar galima naudoti _pokalbių_ pranešimuose",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Dabar botams kurti galima naudoti „Webhooks“. Daugiau informacijos rasite dokumentacijoje: https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Nustatykite priminimą prie pokalbio žinutės, kad vėliau gautumėte dar vieną pranešimą",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Naudokite pokalbių funkciją „**Pastaba sau**“, kad darytumėte užrašus ir dalytumėtės informacija tarp savo įrenginių",
    "- Captions allow to send a message with a file at the same time" : "- Naudojant antraštes galima vienu metu išsiųsti žinutę ir failą",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- Dabar dalijantis ekranu matomas pranešėjo vaizdas, o reakcijos į skambutį yra animuotos",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Prisijungę autoriai ir moderatoriai dabar gali redaguoti pranešimus per 6 valandas",
    "- Unsent message drafts are now saved in your browser" : "- Neišsiųstų žinučių juodraščiai dabar saugomi jūsų naršyklėje",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Dabar galima bendrauti tekstiniu pokalbiu su kitais „Pokalbiai“ serveriais naudojant federacijos funkciją",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Moderatoriai dabar gali užblokuoti paskyras ir svečius, kad šie negalėtų vėl prisijungti prie pokalbio",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "– Pokalbiuose dabar rodomi būsimi skambučiai iš susietų kalendoriaus įvykių ir pavaduojančių asmenų, kurių nėra biure.",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Skambučiai dabar gali būti atliekami federaciniu būdu su kitais „Pokalbių“ serveriais (reikalinga didelio našumo posistemė)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Pristatome Nextcloud „Pokalbiai“ darbalaukio klientą, skirtą „Windows“, „macOS“ ir „Linux“: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Apibendrinkite skambučių įrašus ir neskaitytus pranešimus pokalbiuose naudodami „Nextcloud Asistentas“",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Patobulinti susitikimai: svečių, pakviestų pagal jų el. pašto adresą, importuojami dalyvių sąrašai, apklausų juodraščiai ir atsisiunčiami skambučių dalyvių sąrašai",
    "- Archive conversations to stay focused" : "- Archyvuokite pokalbius, kad išliktumėte susikaupę",
    "- Schedule a meeting into your calendar from within a conversation" : "- Suplanuokite susitikimą į savo kalendorių iš pokalbio",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Ieškokite dabartinio pokalbio pranešimų tiesiai dešinėje šoninėje juostoje",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "– Iš pirmo žvilgsnio peržiūrėkite daugiau pokalbių naudodami naują kompaktišką sąrašą (įjunkite „Pokalbiai“ nustatymuose)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Susitikimų pokalbiai dabar sinchronizuoja pavadinimą ir aprašymą iš kalendoriaus ir yra paslėpti naudojant paieškos filtrą, kol nepriartėja prie pradžios.",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Pranešimų nustatymuose pažymėkite pokalbius kaip jautrius, kad paslėptumėte pranešimo turinį pokalbių sąraše ir pranešimuose",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Norėdami gauti tiesioginius pranešimus režimu „Netrukdyti“, pažymėkite pokalbius kaip svarbius",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Įtraukite kitus dalyvius į individualų skambutį, kad iš karto sukurtumėte naują grupinį skambutį",
    "- Use threads to keep your chat and discussions organized" : "- Naudokite temas, kad pokalbiai ir diskusijos būtų tvarkingos",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Dabar skambučio metu galima naudotis tiesioginėmis transkripcijomis (reikalinga tiesioginės transkripcijos „ExApp“ ir didelio našumo vidinė sistema).",
    "- Moderators can now pin messages so they are kept at the top" : "- Moderatoriai dabar gali prisegti žinutes, kad jos būtų rodomos viršuje",
    "- Schedule a message to send it at a later time" : "- Suplanuokite žinutės išsiuntimą vėliau",
    "- Conversation tags, grouping and sorting to organize the conversation list" : "- Pokalbių žymos, grupavimas ir rūšiavimas pokalbių sąrašui tvarkyti",
    "- Voice-rooms to connect spontaneously" : "- Bendravimo kambariai, kuriuose galima spontaniškai užmegzti ryšį",
    "- Presets for quick conversation configuration during creation" : "- Iš anksto nustatyti parametrai, leidžiantys greitai sukonfigūruoti pokalbį jo kūrimo metu",
    "- Direct calls from profile menus for calls within other apps" : "- Tiesioginiai skambučiai iš profilio meniu skambučiams kitose programėlėse",
    "_All %n participant_::_All %n participants_" : ["Visi %n dalyvių","Visi %n dalyviai","Visi %n dalyvių","Visi %n dalyvių"],
    "Talk updates ✅" : "Pokalbių programėlės atnaujinimai ✅",
    "Reaction deleted by author" : "Autorius ištrynė reakciją",
    "{actor} created the conversation" : "{actor} sukūrė pokalbį",
    "You created the conversation" : "Jūs sukūrėte pokalbį",
    "System created the conversation" : "Sistema sukūrė pokalbį",
    "An administrator created the conversation" : "Administratorius sukūrė pokalbį",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Jūs pervadinote pokalbį iš \"%1$s\" į \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Administratorius pervadino pokalbį iš \"%1$s\" į \"%2$s\"",
    "{actor} set the description" : "{actor} nustatė aprašą",
    "You set the description" : "Jūs nustatėte aprašą",
    "An administrator set the description" : "Administratorius nustatė aprašą",
    "{actor} removed the description" : "{actor} pašalino aprašą",
    "You removed the description" : "Jūs pašalinote aprašą",
    "An administrator removed the description" : "Administratorius pašalino aprašą",
    "You started a silent call" : "Jūs pradėjote tylų skambutį",
    "Outgoing silent call" : "Išeinantis tylus skambutis",
    "{actor} started a silent call" : "{actor} pradėjo tylų skambutį",
    "Incoming silent call" : "Įeinantis tylus skambutis",
    "You started a call" : "Jūs pradėjote skambutį",
    "Outgoing call" : "Išeinantis skambutis",
    "{actor} started a call" : "{actor} pradėjo skambutį",
    "Incoming call" : "Įeinantis skambutis",
    "{actor} joined the call" : "{actor} prisijungė prie skambučio",
    "You joined the call" : "Jūs prisijungėte prie skambučio",
    "{actor} left the call" : "{actor} išėjo iš skambučio",
    "You left the call" : "Jūs išėjote iš skambučio",
    "{actor} unlocked the conversation" : "{actor} atrakino pokalbį",
    "You unlocked the conversation" : "Jūs atrakinote pokalbį",
    "An administrator unlocked the conversation" : "Administratorius atrakino pokalbį",
    "{actor} locked the conversation" : "{actor} užrakino pokalbį",
    "You locked the conversation" : "Jūs užrakinote pokalbį",
    "An administrator locked the conversation" : "Administratorius užrakino pokalbį",
    "{actor} limited the conversation to the current participants" : "{actor} apribojo pokalbį iki dabartinių dalyvių",
    "You limited the conversation to the current participants" : "Jūs apribojote pokalbį iki dabartinių dalyvių",
    "An administrator limited the conversation to the current participants" : "Administratorius apribojo pokalbį iki dabartinių dalyvių",
    "{actor} opened the conversation to registered users" : "{actor} atvėrė pokalbį registruotiems naudotojams",
    "You opened the conversation to registered users" : "Jūs atvėrėte pokalbį registruotiems naudotojams",
    "An administrator opened the conversation to registered users" : "Administratorius atvėrė pokalbį registruotiems naudotojams",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} atidarė pokalbį registruotiems vartotojams ir vartotojams, sukurtiems naudojant svečių programėlę",
    "You opened the conversation to registered users and users created with the Guests app" : "Atidarėte pokalbį registruotiems vartotojams ir vartotojams, sukurtiems naudojant svečių programėlę.",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Administratorius atidarė pokalbį registruotiems vartotojams ir vartotojams, sukurtiems naudojant svečių programėlę.",
    "The conversation is now open to everyone" : "Dabar, pokalbis yra atviras visiems",
    "{actor} opened the conversation to everyone" : "{actor} atvėrė pokalbį visiems",
    "You opened the conversation to everyone" : "Jūs atvėrėte pokalbį visiems",
    "{actor} restricted the conversation to moderators" : "{actor} apribojo pokalbį iki moderatorių",
    "You restricted the conversation to moderators" : "Jūs apribojote pokalbį iki moderatorių",
    "{actor} started breakout rooms" : "{actor} sukūrė grupinio darbo kambarius",
    "You started breakout rooms" : "Sukūrėte grupinio darbo kambarius",
    "{actor} stopped breakout rooms" : "{actor} sustabdė grupinio darbo kambarius",
    "You stopped breakout rooms" : "Jūs sustabdėte grupinio darbo kambarius",
    "{actor} allowed guests" : "{actor} leidžia svečius",
    "You allowed guests" : "Jūs leidote svečius",
    "An administrator allowed guests" : "Administratorius leido svečius",
    "{actor} disallowed guests" : "{actor} nebeleidžia svečių",
    "You disallowed guests" : "Jūs nebeleidžiate svečių",
    "An administrator disallowed guests" : "Administratorius nebeleidžia svečių",
    "{actor} set a password" : "{actor} nustatė slaptažodį",
    "You set a password" : "Jūs nustatėte slaptažodį",
    "An administrator set a password" : "Administratorius nustatė slaptažodį",
    "{actor} removed the password" : "{actor} pašalino slaptažodį",
    "You removed the password" : "Jūs pašalinote slaptažodį",
    "An administrator removed the password" : "Administratorius pašalino slaptažodį",
    "{actor} added {user}" : "{actor} pridėjo naudotoją {user}",
    "You joined the conversation" : "Jūs prisijungėte prie pokalbio",
    "{actor} joined the conversation" : "{actor} prisijungė prie pokalbio",
    "You added {user}" : "Jūs pridėjote naudotoją {user}",
    "{actor} added you" : "{actor} jus pridėjo",
    "An administrator added you" : "Administratorius jus pridėjo",
    "An administrator added {user}" : "Administratorius pridėjo vartotoją {user}",
    "You left the conversation" : "Jūs išėjote iš pokalbio",
    "{actor} left the conversation" : "{actor} išėjo iš pokalbio",
    "{actor} removed {user}" : "{actor} pašalino naudotoją {user}",
    "You removed {user}" : "Jūs pašalinote naudotoją {user}",
    "{actor} removed you" : "{actor} jus pašalino",
    "An administrator removed you" : "Administratorius jus pašalino",
    "An administrator removed {user}" : "Administratorius pašalino vartotoją {user}",
    "{actor} invited {federated_user}" : "{actor} pakvietė {federated_user}",
    "You invited {federated_user}" : "Jūs pakvietėte {federated_user}",
    "You accepted the invitation" : "Jūs priėmėte pakvietimą",
    "{actor} invited you" : "{actor} pakvietė jus",
    "An administrator invited you" : "Administratorius jus pakvietė",
    "An administrator invited {federated_user}" : "Administratorius pakvietė {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} kvietimą priėmė",
    "{actor} removed {federated_user}" : "{actor} pašalino {federated_user}",
    "You removed {federated_user}" : "Jūs pašalinote  {federated_user}",
    "You declined the invitation" : "Jūs atmetėte pakvietimą",
    "An administrator removed {federated_user}" : "Administratorius pašalino vartotoją {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} atmetė pakvietimą",
    "{actor} added group {group}" : "{actor} pridėjo grupę {group}",
    "You added group {group}" : "Jūs pridėjote grupę {group}",
    "An administrator added group {group}" : "Administratorius pridėjo grupę {group}",
    "{actor} removed group {group}" : "{actor} pašalino grupę {group}",
    "You removed group {group}" : "Jūs pašalinote grupę {group}",
    "An administrator removed group {group}" : "Administratorius pašalino grupę {group}",
    "{actor} added team {circle}" : "{actor} pridėjo komandą {circle}",
    "You added team {circle}" : "Jūs pridėjote komandą {circle}",
    "An administrator added team {circle}" : "Administratorius pridėjo komandą {circle}",
    "{actor} removed team {circle}" : "{actor} pašalino komandą {circle}",
    "You removed team {circle}" : "Jūs pašalinote komandą {circle}",
    "An administrator removed team {circle}" : "Administratorius pašalino komandą {circle}",
    "{actor} added {phone}" : "{actor} pridėjo {phone}",
    "You added {phone}" : "Jūs pridėjote {phone}",
    "An administrator added {phone}" : "Administratorius pridėjo {phone}",
    "{actor} removed {phone}" : "{actor} pašalino {phone}",
    "You removed {phone}" : "Jūs pašalinote {phone}",
    "An administrator removed {phone}" : "Administratorius pašalino {phone}",
    "{actor} promoted {user} to moderator" : "{actor} paaukštino vartotoją {user} į moderatorius",
    "You promoted {user} to moderator" : "Jūs paaukštinote vartotoją {user} į moderatorius",
    "{actor} promoted you to moderator" : "{actor} paaukštino jus į moderatorius",
    "An administrator promoted you to moderator" : "Administratorius paaukštino jus į moderatorius",
    "An administrator promoted {user} to moderator" : "Administratorius paaukštino vartotoją {user} į moderatorius",
    "{actor} demoted {user} from moderator" : "{actor} pašalino {user} iš moderatoriaus pareigų",
    "You demoted {user} from moderator" : "Jūs pašalinote {user} iš moderatorių",
    "{actor} demoted you from moderator" : "{actor} pažemino jus iš moderatorių",
    "An administrator demoted you from moderator" : "Administratorius pažemino jus iš moderatorių",
    "An administrator demoted {user} from moderator" : "Administratorius pažemino vartotoją {user} iš moderatorių",
    "{actor} shared a file which is no longer available" : "{actor} pradėjo bendrinti failą, kuris daugiau nebeprieinamas",
    "You shared a file which is no longer available" : "Jūs pradėjote bendrinti failą, kuris daugiau nebeprieinamas",
    "File shares are currently not supported in federated conversations" : "Failų bendrinimas šiuo metu nepalaikomas sujungtuose pokalbiuose",
    "The shared location is malformed" : "Bendrinama vieta yra netinkamai suformuota",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} nustatė „Matterbridge“, kad šis pokalbis būtų sinchronizuojamas su kitais pokalbiais",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Jūs nustatėte „Matterbridge“, kad šis pokalbis būtų sinchronizuojamas su kitais pokalbiais",
    "{actor} created thread {title}" : "{actor} sukūrė temą {title}",
    "You created thread {title}" : "Jūs sukūrėte temą {title}",
    "{actor} renamed thread {title}" : "{actor} pakeitė temos pavadinimą {title}",
    "You renamed thread {title}" : "Jūs pakeitėte temos pavadinimą {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} atnaujino „Matterbridge“ konfigūraciją",
    "You updated the Matterbridge configuration" : "Jūs atnaujinote „Matterbridge“ konfigūraciją",
    "{actor} removed the Matterbridge configuration" : "{actor} pašalino „Matterbridge“ konfigūraciją",
    "You removed the Matterbridge configuration" : "Jūs pašalinote „Matterbridge“ konfigūraciją",
    "{actor} started Matterbridge" : "{actor}  pradėjo „Matterbridge“",
    "You started Matterbridge" : "Jūs pradėjote „Matterbridge“.",
    "{actor} stopped Matterbridge" : "{actor} sustabdė Matterbridge",
    "You stopped Matterbridge" : "Sustabdėte Matterbridge",
    "{actor} deleted a message" : "{actor} ištrynė žinutę",
    "You deleted a message" : "Jūs ištrynėte žinutę",
    "{actor} edited a message" : "{actor} redagavo žinutę",
    "You edited a message" : "Jūs redagavote žinutę",
    "{actor} pinned a message" : "{actor} prisegė žinutę",
    "You pinned a message" : "Jūs prisegėte žnutę",
    "{actor} unpinned a message" : "{actor} atsegė žinutę",
    "Message was automatically unpinned" : "Žinutė buvo automatiškai atsegta",
    "You unpinned a message" : "Atsegėte pranešimą",
    "{actor} deleted a reaction" : "{actor} ištrynė reakciją",
    "You deleted a reaction" : "Jūs ištrynėte reakciją",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Nustatėte pranešimo galiojimo laiką iki %n savaitės","Nustatėte pranešimo galiojimo laiką iki %n savaičių","Nustatėte pranešimo galiojimo laiką iki %n savaičių","Nustatėte pranešimo galiojimo laiką iki %n savaičių"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Nustatėte pranešimo galiojimo laiką iki %n dienos","Nustatėte pranešimo galiojimo laiką iki %n dienų","Nustatėte pranešimo galiojimo laiką iki %n dienų","Nustatėte pranešimo galiojimo laiką iki %n dienų"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Nustatėte pranešimo galiojimo laiką iki %n valandos","Nustatėte pranešimo galiojimo laiką iki %n valandų","Nustatėte pranešimo galiojimo laiką iki %n valandų","Nustatėte pranešimo galiojimo laiką iki %n valandų"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Nustatėte pranešimo galiojimo laiką iki %n minutės","Nustatėte pranešimo galiojimo laiką iki %n minučių","Nustatėte pranešimo galiojimo laiką iki %n minučių","Nustatėte pranešimo galiojimo laiką iki %n minučių"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} nustatė pranešimo galiojimo laiką iki %n savaitės","{actor} nustatė pranešimo galiojimo laiką iki %n savaičių","{actor} nustatė pranešimo galiojimo laiką iki %n savaičių","{actor} nustatė pranešimo galiojimo laiką iki %n savaičių"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} nustatė pranešimo galiojimo laiką iki %n dienos","{actor} nustatė pranešimo galiojimo laiką iki %n dienų","{actor} nustatė pranešimo galiojimo laiką iki %n dienų","{actor} nustatė pranešimo galiojimo laiką iki %n dienų"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor}nustatė pranešimo galiojimo laiką iki %n valandos","{actor}nustatė pranešimo galiojimo laiką iki %n valandų","{actor} nustatė pranešimo galiojimo laiką iki %n valandų","{actor} nustatė pranešimo galiojimo laiką iki %n valandų"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} nustatė pranešimo galiojimo laiką iki %n minutės","{actor} nustatė pranešimo galiojimo laiką iki %n minučių","{actor} nustatė pranešimo galiojimo laiką iki %n minučių","{actor} nustatė pranešimo galiojimo laiką iki %n minučių"],
    "{actor} disabled message expiration" : "{actor} išjungė pranešimo galiojimo laiką",
    "You disabled message expiration" : "Išjungėte pranešimo galiojimo laiką",
    "{actor} cleared the history of the conversation" : "{actor} išvalė pokalbio istoriją",
    "You cleared the history of the conversation" : "Jūs išvalėte pokalbio istoriją",
    "{actor} set the conversation picture" : "{actor} nustatė pokalbio vaizdą",
    "You set the conversation picture" : "Jūs nustatėte pokalbio paveikslėlį",
    "{actor} removed the conversation picture" : "{actor} pašalino pokalbio nuotrauką",
    "You removed the conversation picture" : "Pašalinote pokalbio paveiksėlį",
    "{actor} ended the poll {poll}" : "{actor} baigė apklausą {poll}",
    "You ended the poll {poll}" : "Jūs baigėte apklausą {poll}",
    "{actor} started the video recording" : "{actor} pradėjo vaizdo įrašymą ",
    "You started the video recording" : "Pradėjote vaizdo įrašymą",
    "{actor} stopped the video recording" : "{actor} sustabdė vaizdo įrašymą",
    "You stopped the video recording" : "Jūs sustabdėte vaizdo įrašymą",
    "{actor} started the audio recording" : "{actor} pradėjo garso įrašymą",
    "You started the audio recording" : "Pradėjote garso įrašymą",
    "{actor} stopped the audio recording" : "{actor} sustabdė garso įrašymą",
    "You stopped the audio recording" : "Sustabdėte garso įrašymą",
    "The recording failed" : "Įrašyti nepavyko",
    "Someone voted on the poll {poll}" : "Kažkas balsavo apklausoje {poll}",
    "Message deleted by author" : "Autorius ištrynė žinutę",
    "Message deleted by {actor}" : "{actor} ištrynė žinutę",
    "Message deleted by you" : "Jūs ištrynėte žinutę",
    "Deleted user" : "Ištrintas naudotojas",
    "Unknown number" : "Nežinomas numeris",
    "Administration" : "Administravimas",
    "System" : "Sistema",
    "%s (guest)" : "%s (svečias)",
    "Missed call" : "Praleistas skambutis",
    "Unanswered call" : "Neatsakytas skambutis",
    "Call ended (Duration {duration})" : "Skambutis baigtas (Trukmė {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Skambutis buvo užbaigtas, nes jis pasiekė didžiausią skambučio trukmę (Trukmė {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} užbaigė skambutį (Trukmė {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Skambutis su %n svečiu buvo baigtas, nes pasiekė maksimalią skambučio trukmę (trukmė {duration})","Skambutis su %nsvečiais buvo baigtas, nes pasiekė maksimalią skambučio trukmę (trukmė {duration})","Skambutis su %n svečių buvo baigtas, nes pasiekė maksimalią skambučio trukmę (trukmė {duration})","Skambutis su %n svečių buvo baigtas, nes pasiekė maksimalią skambučio trukmę (trukmė {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Skambutis su %n svečiu buvo baigtas (trukmė {duration})","Skambutis su %n svečiais buvo baigtas (trukmė {duration})","Skambutis su %n svečių buvo baigtas (trukmė {duration})","Skambutis su %n svečių buvo baigtas (trukmė {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} baigė skambutį su %n svečiu (trukmė {duration})","{actor} baigė skambutį su %n svečiais (trukmė {duration})","{actor} baigė skambutį su %n svečių (trukmė {duration})","{actor} baigė skambutį su %n svečių (trukmė {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Skambutis su {user1}buvo baigtas, nes pasiekta maksimali skambučio trukmė (trukmė {duration})",
    "Call with {user1} ended (Duration {duration})" : "Skambutis su {user1} pasibaigė (trukmė {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} baigė skambutį su {user1} (trukmė {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Skambutis su {user1} ir {user2} buvo baigtas, nes pasiekta maksimali skambučio trukmė (trukmė {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Skambutis su {user1} ir {user2} pasibaigė (trukmė {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} baigė skambutį su {user1} ir {user2} (trukmė {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Skambutis su {user1}, {user2} ir {user3} buvo baigtas, nes pasiekta maksimali skambučio trukmė (trukmė {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Skambutis su {user1}, {user2} ir {user3} pasibaigė (trukmė {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} baigė skambutų su {user1}, {user2} ir {user3} (trukmė {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Skambutis su {user1}, {user2}, {user3} ir {user4} buvo baigtas, nes pasiekta maksimali skambučio trukmė (trukmė {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Skambutis su {user1}, {user2}, {user3} ir {user4} pasibaigė (trukmė {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} baigė skambutį su {user1}, {user2}, {user3} ir {user4} (trukmė {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Skambutis su {user1}, {user2}, {user3}, {user4} ir {user5} buvo baigtas, nes pasiekta maksimali skambučio trukmė (trukmė {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Skambutis su {user1}, {user2}, {user3}, {user4} ir {user5} buvo baigtas (trukmė {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} baigė kambutį su {user1}, {user2}, {user3}, {user4} ir {user5} (trukmė {duration})",
    "Message of {user} in {conversation}" : "Žinutė iš {user}, {conversation} pokalbyje",
    "Message of {user}" : "Žinutė iš {user}",
    "Message of a deleted user in {conversation}" : "Ištrinto vartotojo žinutė {conversation} pokalbyje",
    "Talk conversations" : "„Pokalbių“ pokalbiai",
    "Call %s" : "Skambinti %s",
    "Chat with %s" : "Pokalbis su %s",
    "An error occurred. Please contact your administrator." : "Įvyko klaida. Susisiekite su administratoriumi.",
    "App disabled" : "Programėlė išjungta",
    "Conversation subfolders are disabled" : "Pokalbių pakatalogiai yra išjungti",
    "Storage quota exceeded" : "Viršyta saugyklos kvota",
    "Could not prepare conversation folder" : "Nepavyko paruošti pokalbių aplanko",
    "File not found" : "Failas nerastas",
    "Path must point to a file" : "Kelias turi nurodyti failą",
    "File is not inside the conversation draft folder for this room" : "Failas nėra šio pokalbių kambario pokalbių juodraščių aplanke",
    "File is not shared, or shared but not with the user" : "Failas nėra bendrinamas arba yra bendrinamas, tačiau ne su vartotoju",
    "No account available to delete." : "Nėra ištrynimui prieinamos paskyros.",
    "Poll" : "Apklausa",
    "Password needs to be set" : "Turi būti nustatytas slaptažodis",
    "Uploading the file failed" : "Nepavyko įkelti failo",
    "No image file provided" : "Paveikslėlio failas nepateiktas",
    "File is too big" : "Failas yra per didelis",
    "Invalid file provided" : "Pateiktas neteisingas failas",
    "Invalid image" : "Netinkamas paveikslas",
    "Unknown filetype" : "Nežinomas failo tipas",
    "Talk mentions" : "Paminėjimai pokalbiuose",
    "More conversations" : "Daugiau pokalbių",
    "Say hi to your friends and colleagues!" : "Pasisveikinkite su savo draugais ir kolegomis!",
    "No unread mentions" : "Nėra neskaitytų paminėjimų",
    "Call in progress" : "Skambutis vyksta",
    "You were mentioned" : "Jūs buvote paminėti",
    "Write to conversation" : "Rašyti į pokalbį",
    "Writes event information into a conversation of your choice" : "Parašo apie įvykio informaciją į jūsų pasirinktą pokalbį",
    "Missing email field in header line" : "Antraštės eilutėje trūksta lauko „El. paštas“",
    "Following lines are invalid: %s" : "Šios eilutės yra neteisingos: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s pakvietė jus į pokalbį „%2$s“.",
    "You were invited to conversation \"%s\"." : "Buvote pakviestas į pokalbį „%s“.",
    "Conversation invitation" : "Pakvietimas į pokalbį",
    "Scheduled time" : "Numatytas laikas",
    "Description" : "Aprašas",
    "You can also dial-in via phone with the following details" : "Taip pat galite prisijungti telefonu, naudodami šiuos duomenis",
    "Dial-in information" : "Skambinimo informacija",
    "Meeting ID" : "Susitikimo ID",
    "Your PIN" : "Jūsų PIN kodas",
    "Click the button below to join the lobby now." : "Norėdami prisijungti prie laukiamojo dabar, spustelėkite žemiau esantį mygtuką.",
    "Click the link below to join the lobby now." : "Norėdami prisijungti prie laukiamojo dabar, spustelėkite žemiau esančią nuorodą.",
    "Join lobby for \"%s\"" : "Prisijunkite prie laukiamojo, skirto „%s“",
    "Click the button below to join the conversation now." : "Norėdami prisijungti prie pokalbio dabar, spustelėkite žemiau esantį mygtuką.",
    "Click the link below to join the conversation now." : "Norėdami prisijungti prie pokalbio dabar, spustelėkite žemiau esančią nuorodą.",
    "Join \"%s\"" : "Prisijungti „%s“",
    "Meeting" : "Susitikimas",
    "Password request: %s" : "Slaptažodžio prašymas: %s",
    "Private conversation" : "Privatus pokalbis",
    "Deleted user (%s)" : "Ištrintas naudotojas (%s)",
    "Failed to upload call recording" : "Nepavyko įkelti skambučio įrašo",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "Įrašymo serveriui nepavyko įkelti {call} skambučio įrašo. Susisiekite su administracija.",
    "Share to chat" : "Bendrinkite, kad galėtumėte kalbėtis",
    "Dismiss notification" : "Atmesti pranešimą",
    "Call recording now available" : "Dabar galimas skambučių įrašymas",
    "The recording for the call in {call} was uploaded to {file}." : "Skambučio {call} įrašas buvo įkeltas į {file}.",
    "Transcript now available" : "Nuorašas dabar prieinamas",
    "The transcript for the call in {call} was uploaded to {file}." : "Skambučio {call} transkripcija buvo įkelta į {file}.",
    "Failed to transcript call recording" : "Nepavyko transkribuoti skambučio įrašo",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "Serveriui nepavyko transkribuoti įrašo, esančio {file}, susijusio su skambučiu {call}. Prašome kreiptis į administraciją.",
    "Call summary now available" : "Dabar pasiekiama skambučių suvestinė",
    "The summary for the call in {call} was uploaded to {file}." : "{call} skambučio santrauka buvo įkelta į {file}.",
    "Failed to summarize call recording" : "Nepavyko apibendrinti skambučio įrašo",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "Serveriui nepavyko apibendrinti įrašo {file}, susijusio su skambučiu {call}. Kreipkitės į administraciją.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} pakvietė jus prisijungti į {roomName} esančiame {remoteServer}",
    "Accept" : "Priimti",
    "Decline" : "Atmesti",
    "{user1} invited you to a federated conversation" : "{user1} pakvietė jus į federacinį pokalbį",
    "Someone reacted" : "Kažkas sureagavo",
    "New message" : "Nauja žinutė",
    "Reminder" : "Priminimas",
    "Someone mentioned you" : "Kažkas jus paminėjo",
    "Notification" : "Pranešimas",
    "Someone reacted in a private conversation" : "Kažkas sureagavo privačiame pokalbyje",
    "You received a message in a private conversation" : "Gavote žinutę asmeniniame pokalbyje",
    "Reminder in a private conversation" : "Priminimas privačiame pokalbyje",
    "Someone mentioned you in a private conversation" : "Kažkas jus paminėjo privačiame pokalbyje",
    "Notification in a private conversation" : "Pranešimas privačiame pokalbyje",
    "Reminder: You in {call}" : "Priminimas: Jūs esate {call}",
    "Reminder: {user} in {call}" : "Priminimas: {user} yra {call}",
    "Reminder: Deleted user in {call}" : "Priminimas: pašalintas vartotojas iš {call}",
    "Reminder: {guest} (guest) in {call}" : "Priminimas: {guest} (svečias) yra {call}",
    "Reminder: Guest in {call}" : "Priminimas: svečias {call}",
    "{user} reacted with {reaction}" : "{user} sureagavo {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} sureagavo {reaction} pokalbyje {call}",
    "Deleted user reacted with {reaction} in {call}" : "Ištrintas naudotojas sureagavo {reaction} pokalbyje {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (svečias) sureagavo {reaction} pokalbyje {call}",
    "Guest reacted with {reaction} in {call}" : "Svečias sureagavo {reaction} pokalbyje {call}",
    "{user} in {call}" : "{user} lentelėje {call}",
    "Deleted user in {call}" : "Ištrintas vartotojas iš {call}",
    "{guest} (guest) in {call}" : "{guest} (svečias) {call}",
    "Guest in {call}" : "Svečias {call}",
    "{user} sent you a private message" : "{user} išsiuntė jums privačią žinutę",
    "{user} sent a message in conversation {call}" : "{user} išsiuntė žinutę pokalbyje {call}",
    "A deleted user sent a message in conversation {call}" : "Ištrintas vartotojas išsiuntė žinutę pokalbyje {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (svečias) išsiuntė žinutę pokalbyje {call}",
    "A guest sent a message in conversation {call}" : "Svečias išsiuntė žinutę pokalbyje {call}",
    "{user} replied to your private message" : "{user} atsakė į jūsų privačią žinutę",
    "{user} replied to your message in conversation {call}" : "{user} atsakė į jūsų žinutę pokalbyje {call}",
    "A deleted user replied to your message in conversation {call}" : "Ištrintas vartotojas atsakė į jūsų žinutę pokalbyje {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (svečias) atsakė į jūsų žinutę pokalbyje {call}",
    "A guest replied to your message in conversation {call}" : "Svečias atsakė į jūsų žinutę pokalbyje {call}",
    "Reminder: You in private conversation {call}" : "Priminimas: Jūs dalyvaujate privačiame pokalbyje {call}",
    "Reminder: A deleted user in private conversation {call}" : "Priminimas: ištrintas vartotojas privačiame pokalbyje{call}",
    "Reminder: {user} in private conversation" : "Priminimas: {user} privačiame pokalbyje",
    "Reminder: You in conversation {call}" : "Priminimas: Jūs dalyvaujate pokalbyje {call}",
    "Reminder: {user} in conversation {call}" : "Priminimas: {user} pokalbyje {call}",
    "Reminder: A deleted user in conversation {call}" : "Priminimas: ištrintas vartotojas pokalbyje{call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Priminimas: {guest} (svečias) pokalbyje {call}",
    "Reminder: A guest in conversation {call}" : "Priminimas: svečias pokalbyje {call}",
    "{user} reacted with {reaction} to your private message" : "{user} sureagavo {reaction} į jūsų privačią žinutę",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} sureagavo {reaction} į jūsų žinutę {call} pokalbyje",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Ištrintas vartotojas sureagavo {reaction} į jūsų žinutę {call} pokalbyje",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (svečias) sureagavo {reaction} į jūsų žinutę {call} pokalbyje",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Svečias sureagavo {reaction} į jūsų žinutę {call} pokalbyje",
    "{user} mentioned you in a private conversation" : "{user} paminėjo jus privačiame pokalbyje",
    "{user} mentioned group {group} in conversation {call}" : "{user} paminėjo {group} grupę {call} pokalbyje",
    "{user} mentioned team {team} in conversation {call}" : "{user} paminėjo {team} komandą {call} pokalbyje",
    "{user} mentioned everyone in conversation {call}" : "{user} paminėjo visus {call} pokalbyje",
    "{user} mentioned you in conversation {call}" : "{user} paminėjo jus pokalbyje {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Ištrintas vartotojas paminėjo {group} grupę {call} pokalbyje",
    "A deleted user mentioned team {team} in conversation {call}" : "Ištrintas vartotojas {team} komandą {call} pokalbyje",
    "A deleted user mentioned everyone in conversation {call}" : "Ištrintas vartotojas paminėjo kiekvieną {call} pokalbyje",
    "A deleted user mentioned you in conversation {call}" : "Ištrintas vartotojas paminėjo jus {call} pokalbyje",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (svečias) paminėjo {group} grupę {call} pokalbyje",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (svečias) paminėjo {team} komandą  {call} pokalbyje",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (svečias) paminėjo kiekvieną {call} pokalbyje",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (svečias) paminėjo jus pokalbyje {call}",
    "A guest mentioned group {group} in conversation {call}" : "Svečias paminėjo {group} grupę {call} pokalbyje",
    "A guest mentioned team {team} in conversation {call}" : "Svečias paminėjo {team} komandą  {call} pokalbyje",
    "A guest mentioned everyone in conversation {call}" : "Svečias paminėjo kiekvieną {call} pokalbyje",
    "A guest mentioned you in conversation {call}" : "Svečias paminėjo jus pokalbyje {call}",
    "View message" : "Rodyti žinutę",
    "Dismiss reminder" : "Atmesti priminimą",
    "View chat" : "Rodyti pokalbį",
    "{user} invited you to a group conversation: {call}" : "{user} jus pakvietė į grupės pokalbį: {call}",
    "Join call" : "Prisijungti prie skambučio",
    "Answer call" : "Atsiliepti",
    "{user} would like to talk with you" : "{user} norėtų su jumis pakalbėti",
    "Call back" : "Atskambinti",
    "You missed a call from {user}" : "Jūs praleidote skambutį nuo {user}",
    "Accept call" : "Priimti skambutį",
    "Incoming phone call from {call}" : "Įeinantis telefono skambutis iš {call}",
    "You missed a phone call from {call}" : "Jūs praleidote grupės skambutį iš {call}",
    "A group call has started in {call}" : "Grupės skambutis prasidėjo ties {call}",
    "You missed a group call in {call}" : "Jūs praleidote grupės skambutį ties {call}",
    "{email} is requesting the password to access {file}" : "{email} prašo slaptažodžio, kad gautų prieigą prie {file}",
    "{email} tried to request the password to access {file}" : "{email} bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
    "Someone is requesting the password to access {file}" : "Kažkas prašo slaptažodžio, kad gautų prieigą prie {file}",
    "Someone tried to request the password to access {file}" : "Kažkas bandė paprašyti slaptažodžio, kad gautų prieigą prie {file}",
    "Open settings" : "Atverti nustatymus",
    "Hosted signaling server added" : "Signalinio ryšio serveris pridėtas",
    "The hosted signaling server is now configured and will be used." : "Signalinio ryšio serveris dabar sukonfigūruotas ir bus naudojamas.",
    "Hosted signaling server removed" : "Signalinio ryšio serveris pašalintas",
    "The hosted signaling server was removed and will not be used anymore." : "Signalinio ryšio serveris buvo pašalintas ir daugiau nebus naudojamas.",
    "Hosted signaling server changed" : "Signalinio ryšio serveris pakeistas",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Signalinio ryšio serverio paskyros būsena pasikeitė iš „{oldstatus}“ į „{newstatus}“.",
    "pending" : "laukiama",
    "active" : "aktyvus",
    "expired" : "pasibaigęs",
    "blocked" : "užblokuotas",
    "error" : "klaida",
    "The certificate of {host} expires in {days} days" : "Sertifikato {host} galiojimo laikas baigiasi po {days} dienų",
    "The certificate of {host} expired" : "{host} sertifikatas nebegalioja",
    "Contact via Talk" : "Susisiekti per „Pokalbius“",
    "Open Talk" : "Atverti pokalbius",
    "Call via Talk" : "Skambutis per „Pokalbius“",
    "Default" : "Numatytoji",
    "Send messages, create threads, and start voice and video calls." : "Siųskite žinutes, kurkite diskusijas ir pradėkite balso bei vaizdo skambučius.",
    "Presentation" : "Pateiktis",
    "Restricted conversation for internal presentations." : "Konfidencialus pokalbis, skirtas vidiniams pristatymams.",
    "Voice room" : "Bendravimo kambarys",
    "Directly join the call, ideal for catch-ups or spontaneous meetings." : "Prisijunkite prie pokalbio tiesiogiai – tai puikus sprendimas, jei norite pasikalbėti ar surengti spontanišką susitikimą.",
    "Webinar" : "Internetinis seminaras",
    "Restricted conversation with lobby enabled, ideal for public webinars." : "Įjungta ribota pokalbių funkcija su pokalbių langu, idealiai tinka viešiesiems internetiniams seminarams.",
    "Conversations" : "Pokalbiai",
    "Messages in current conversation" : "Žinutės dabartiniame pokalbyje",
    "{user}" : "{user}",
    "Messages" : "Žinutės",
    "{user} in {conversation}" : "{user} lentelėje {conversation}",
    "Messages in other conversations" : "Žinutės kituose pokalbiuose",
    "One-to-one rooms always need to show the other users avatar" : "Dviejų asmenų pokalbių kambariuose visada turi būti rodomas kito vartotojo avataras",
    "Invalid emoji character" : "Neteisingas emociuko simbolis",
    "Invalid background color" : "Neteisinga fono spalva",
    "Avatar image is not square" : "Avataro paveikslas nėra kvadratinis",
    "Room {number}" : "Kambarys {number}",
    "Favorites" : "Mėgstamiausi",
    "Other" : "Kita",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Nepavyko pateikti prašymo dėl bandomosios versijos, nes nepavyko prisijungti prie bandomosios versijos serverio. Prašome pabandyti vėliau.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Kilo problemų su šio serverio autentiškumo patvirtinimu. Galbūt iš išorės neįmanoma prisijungti prie jo, kad būtų galima patikrinti jo URL adresą.",
    "Something unexpected happened." : "Nutiko kažkas netikėto.",
    "The URL is invalid." : "URL yra neteisingas.",
    "An HTTPS URL is required." : "Reikalingas HTTPS URL.",
    "The email address is invalid." : "El. pašto adresas yra neteisingas.",
    "The language is invalid." : "Neteisinga kalba.",
    "The country is invalid." : "Neteisinga šalis.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Kilo problema su bandomuoju užklausimu. Daugiau informacijos rasite savo žurnaluose.",
    "Too many requests are send from your servers address. Please try again later." : "Iš jūsų serverio adreso siunčiama per daug užklausų. Prašome pabandyti vėliau.",
    "There is already a trial registered for this Nextcloud instance." : "Šiam „Nextcloud“ elementui jau užregistruota bandomoji versija.",
    "Something unexpected happened. Please try again later." : "Nutiko kažkas netikėto. Vėliau bandykite dar kartą.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Nepavyko užsisakyti bandomosios versijos, nes bandomųjų versijų serveris veikė netinkamai. Prašome pabandyti vėliau.",
    "Trial requested but failed to get account information. Please check back later." : "Buvo pateiktas prašymas išbandyti paslaugą, tačiau nepavyko gauti paskyros duomenų. Prašome pabandyti vėliau.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Kilo problemų su šio užklausos autentiškumo patvirtinimu. Galbūt iš išorės neįmanoma pasiekti šio URL adreso, kad būtų galima jį patikrinti.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Nepavyko gauti paskyros informacijos, nes bandomojo serverio veikimas buvo netinkamas. Prašome pabandyti vėliau.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Kilo problemų gaunant paskyros informaciją. Daugiau informacijos rasite savo žurnaluose.",
    "There is no such account registered." : "Nėra tokios registruotos paskyros.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Nepavyko gauti paskyros informacijos, nes bandomojo serverio pasiekti neįmanoma. Prašome pabandyti vėliau.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Nepavyko ištrinti signalinio ryšio serverio paskyros. Patikrinkite vėliau.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Nepavyko ištrinti paskyros, nes bandomasis serveris veikė netinkamai. Prašome pabandyti vėliau.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Kyla problemų ištrinant paskyrą. Daugiau informacijos rasite savo žurnaluose.",
    "Too many requests are sent from your servers address. Please try again later." : "Iš jūsų serverio adreso siunčiama per daug užklausų. Prašome pabandyti vėliau.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Nepavyko ištrinti paskyros, nes negalima prisijungti prie bandomojo serverio. Prašome pabandyti vėliau.",
    "Note to self" : "Pastaba sau",
    "A place for your private notes, thoughts and ideas" : "Vieta jūsų asmeninėms užrašams, mintims ir idėjoms",
    "Transcript is AI generated and may contain mistakes" : "Transkripcija sukurta dirbtinio intelekto pagalba ir joje gali būti klaidų",
    "Summary is AI generated and may contain mistakes" : "Santrauka sukurta dirbtinio intelekto pagalba ir joje gali būti klaidų",
    "Let's get started!" : "Pradėkime!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Pokalbiai** – tai saugi, savarankiškai diegiama komunikacijos platforma, kuri sklandžiai integruojasi į „Nextcloud“ ekosistemą.\n\n#### Pagrindinės „Nextcloud Pokalbiai“ funkcijos:\n\n* Pokalbiai ir žinutės privačiuose bei grupiniuose pokalbiuose\n* Balso ir vaizdo skambučiai\n* Failų dalijimasis ir integracija su kitomis „Nextcloud“ programėlėmis\n* Konfigūruojami pokalbių nustatymai, moderavimas ir privatumo valdymas\n* Prieiga per internetą, kompiuterį ir mobiliuosius įrenginius (iOS ir Android)\n* Privati ir saugi komunikacija\n\nDaugiau informacijos rasite [vartotojo dokumentacijoje](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "„Nextcloud Pokalbiai“ yra privati ​​ir galinga pranešimų siuntimo programėlė, integruojama su „Nextcloud“. Kalbėkitės privačiuose arba grupiniuose pokalbiuose, bendradarbiaukite balso ir vaizdo skambučiais, organizuokite internetinius seminarus ir renginius, tinkinkite pokalbius ir dar daugiau.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 Tekstų formatavimas, kad pranešimai būtų išsamesni\n\n„Nextcloud Pokalbiuose“ galite naudoti „Markdown“ sintaksę, kad suformatuotumėte savo pranešimus. Pavyzdžiui, galite taikyti **paryškinimą** ar *kursyvą*, arba `pažymėti tekstą kaip kodą`. Galite net kurti lenteles ir įterpti antraštes į tekstą.\n\nReikia ištaisyti rašybos klaidą ar pakeisti formatavimą? Redaguokite pranešimą, spustelėdami „Redaguoti pranešimą“ pranešimo meniu.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Pridėti priedus ir nuorodas\n\nNaudodami mygtuką „+“ pridėkite failus iš savo „Nextcloud Hub“. Dalinkitės elementais iš skilties „Failai“ ir įvairių „Nextcloud“ programėlių. Kai kurios programėlės, pavyzdžiui, „Tekstas“, netgi palaiko interaktyvius valdiklius.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Leiskite pokalbiams vykti sklandžiai: paminėkite vartotojus, reaguokite į pranešimus ir dar daugiau\n\nGalite paminėti visus pokalbio dalyvius naudodami %s arba paminėti konkrečius dalyvius įvedę simbolį „@“ ir pasirinkę jų vardą iš sąrašo.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Galite atsakyti į žinutes, persiųsti jas į kitus pokalbius ar kitiems žmonėms arba nukopijuoti žinutės turinį.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Išnaudokite visas „Išmaniojo rinkiklio“ galimybes\n\nTiesiog įveskite „/“ arba pereikite į meniu „+“, kad atidarytumėte „Išmanųjį rinkiklį“ – čia galėsite prie savo pranešimų pridėti įvairų turinį. Galite nustatyti „Išmanųjį rinkiklį“, kad galėtumėte pridėti elementus iš „Nextcloud“ programėlių, GIF failus, vietoves žemėlapyje, dirbtinio intelekto sukurtą turinį ir dar daugiau.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Pokalbių nustatymų tvarkymas\n\nPokalbių meniu galite pasiekti įvairius nustatymus, skirtus pokalbiams tvarkyti, pavyzdžiui:\n* Redaguoti pokalbio informaciją\n* Tvarkyti pranešimus\n* Taikyti įvairias moderavimo taisykles\n* Konfigūruoti prieigą ir saugumą\n* Įjungti botus\n* ir dar daugiau!",
    "Andorra" : "Andora",
    "United Arab Emirates" : "Jungtiniai Arabų Emyratai",
    "Afghanistan" : "Afganistanas",
    "Antigua and Barbuda" : "Antigva ir Barbuda",
    "Anguilla" : "Angilija",
    "Albania" : "Albanija",
    "Armenia" : "Armėnija",
    "Angola" : "Angola",
    "Antarctica" : "Antarktida",
    "Argentina" : "Argentina",
    "American Samoa" : "Amerikos Samoa",
    "Austria" : "Austrija",
    "Australia" : "Australija",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ålandų salos",
    "Azerbaijan" : "Azerbaidžanas",
    "Bosnia and Herzegovina" : "Bosnija ir Hercegovina",
    "Barbados" : "Barbadosas",
    "Bangladesh" : "Bangladešas",
    "Belgium" : "Belgija",
    "Burkina Faso" : "Burkina Fasas",
    "Bulgaria" : "Bulgarija",
    "Bahrain" : "Bahreinas",
    "Burundi" : "Burundis",
    "Benin" : "Beninas",
    "Saint Barthélemy" : "Sen Bartelemi",
    "Bermuda" : "Bermudai",
    "Brunei Darussalam" : "Brunėjaus Darusalamas",
    "Bolivia, Plurinational State of" : "Bolivija (Daugiatautė Valstybė)",
    "Bonaire, Sint Eustatius and Saba" : "Bonèras, Sìnt Eustãtijus ir Sabà",
    "Brazil" : "Brazilija",
    "Bahamas" : "Bahamos",
    "Bhutan" : "Butanas",
    "Bouvet Island" : "Buvė sala",
    "Botswana" : "Botsvana",
    "Belarus" : "Baltarusija",
    "Belize" : "Belizas",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : " Kokosų (Kilingo) Salos",
    "Congo, the Democratic Republic of the" : "Kongas (Demokratinė Respublika)",
    "Central African Republic" : "Centrinės Afrikos Respublika",
    "Congo" : "Kongas",
    "Switzerland" : "Šveicarija",
    "Côte d'Ivoire" : "Dramblio Kaulo Krantas",
    "Cook Islands" : "Kuko salos",
    "Chile" : "Čilė",
    "Cameroon" : "Kamerūnas",
    "China" : "Kinija",
    "Colombia" : "Kolumbija",
    "Costa Rica" : "Kosta Rika",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Žaliasis Kyšulys",
    "Curaçao" : "Kiurasao",
    "Christmas Island" : "Kalėdų sala",
    "Cyprus" : "Kipras",
    "Czechia" : "Čekija",
    "Germany" : "Vokietija",
    "Djibouti" : "Džibutis",
    "Denmark" : "Danija",
    "Dominica" : "Dominika",
    "Dominican Republic" : "Dominikos Respublika",
    "Algeria" : "Alžyras",
    "Ecuador" : "Ekvadoras",
    "Estonia" : "Estija",
    "Egypt" : "Egiptas",
    "Western Sahara" : "Vakarų Sachara",
    "Eritrea" : "Eritrėja",
    "Spain" : "Ispanija",
    "Ethiopia" : "Etiopija",
    "Finland" : "Suomija",
    "Fiji" : "Fidžis",
    "Falkland Islands (Malvinas)" : "Folklando (Malvinų) salos",
    "Micronesia, Federated States of" : "Mikronezija (Federacinės Valstijos)",
    "Faroe Islands" : "Farerų salos",
    "France" : "Prancūzija",
    "Gabon" : "Gabonas",
    "United Kingdom of Great Britain and Northern Ireland" : "Didžiosios Britanijos ir Šiaurės Airijos Jungtinė Karalystė",
    "Grenada" : "Grenada",
    "Georgia" : "Gruzija-Sakartvelas",
    "French Guiana" : "Prancūzijos Gviana",
    "Guernsey" : "Gernsis",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltaras",
    "Greenland" : "Grenlandija",
    "Gambia" : "Gambija",
    "Guinea" : "Gvinėja",
    "Guadeloupe" : "Gvadelupa",
    "Equatorial Guinea" : "Pusiaujo Gvinėja",
    "Greece" : "Graikija",
    "South Georgia and the South Sandwich Islands" : "Pietų Džordžija ir Pietų Sandvičo Salos",
    "Guatemala" : "Gvatemala",
    "Guam" : "Guamas",
    "Guinea-Bissau" : "Bisau Gvinėja",
    "Guyana" : "Gajana",
    "Hong Kong" : "Honkongas",
    "Heard Island and McDonald Islands" : "Herdo ir Makdonaldo Salos",
    "Honduras" : "Hondūras",
    "Croatia" : "Kroatija",
    "Haiti" : "Haitis",
    "Hungary" : "Vengrija",
    "Indonesia" : "Indonezija",
    "Ireland" : "Airija",
    "Israel" : "Izraelis",
    "Isle of Man" : "Meno Sala",
    "India" : "Indija",
    "British Indian Ocean Territory" : "Indijos Vandenyno Britų Sritis",
    "Iraq" : "Irakas",
    "Iran, Islamic Republic of" : "Iranas (Islamo Respublika)",
    "Iceland" : "Islandija",
    "Italy" : "Italija",
    "Jersey" : "Džersis",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanija",
    "Japan" : "Japonija",
    "Kenya" : "Kenija",
    "Kyrgyzstan" : "Kirgizija",
    "Cambodia" : "Kambodža",
    "Kiribati" : "Kiribatis",
    "Comoros" : "Komorai",
    "Saint Kitts and Nevis" : "Sent Kitsas ir Nevis",
    "Korea, Democratic People's Republic of" : "Korėja (Liaudies Demokratinė Respublika)",
    "Korea, Republic of" : "Korėja (Respublika)",
    "Kuwait" : "Kuveitas",
    "Cayman Islands" : " Kaimanų Salos",
    "Kazakhstan" : "Kazachstanas",
    "Lao People's Democratic Republic" : "Laoso Liaudies Demokratinė Respublika",
    "Lebanon" : "Libanas",
    "Saint Lucia" : "Sent Lusija",
    "Liechtenstein" : "Lichtenšteinas",
    "Sri Lanka" : "Šri Lanka",
    "Liberia" : "Liberija",
    "Lesotho" : "Lesotas",
    "Lithuania" : "Lietuva",
    "Luxembourg" : "Liuksemburgas",
    "Latvia" : "Latvija",
    "Libya" : "Libija",
    "Morocco" : "Marokas",
    "Monaco" : "Monakas",
    "Moldova, Republic of" : "Moldova (Respublika)",
    "Montenegro" : "Juodkalnija",
    "Saint Martin (French part)" : "Sen Martenas (prancūzų dalis)",
    "Madagascar" : "Madagaskaras",
    "Marshall Islands" : "Maršalo salos",
    "North Macedonia" : "Šiaurės Makedonija",
    "Mali" : "Malis",
    "Myanmar" : "Mianmaras",
    "Mongolia" : "Mongolija",
    "Macao" : "Makao",
    "Northern Mariana Islands" : "Marianos Šiaurinės Salos",
    "Martinique" : "Martinika",
    "Mauritania" : "Mauritanija",
    "Montserrat" : "Montseratas",
    "Malta" : "Malta",
    "Mauritius" : "Mauricijus",
    "Maldives" : "Maldyvai",
    "Malawi" : "Malavis",
    "Mexico" : "Meksika",
    "Malaysia" : "Malaizija",
    "Mozambique" : "Mozambikas",
    "Namibia" : "Namibija",
    "New Caledonia" : "Naujoji Kaledonija",
    "Niger" : "Nigeris",
    "Norfolk Island" : "Norfolko Sala",
    "Nigeria" : "Nigerija",
    "Nicaragua" : "Nikaragva",
    "Netherlands" : "Nyderlandai",
    "Norway" : "Norvegija",
    "Nepal" : "Nepalas",
    "Nauru" : "Nauru",
    "Niue" : "Niujė",
    "New Zealand" : "Naujoji Zelandija",
    "Oman" : "Omanas",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Prancūzijos Polinezija",
    "Papua New Guinea" : "Papua Naujoji Gvinėja",
    "Philippines" : "Filipinai",
    "Pakistan" : "Pakistanas",
    "Poland" : "Lenkija",
    "Saint Pierre and Miquelon" : "Sen Pjeras ir Mikelonas",
    "Pitcairn" : "Pitkerno salos",
    "Puerto Rico" : "Puerto Rikas",
    "Palestine, State of" : "Palestinos Valstybė",
    "Portugal" : "Portugalija",
    "Palau" : "Palau",
    "Paraguay" : "Paragvajus",
    "Qatar" : "Kataras",
    "Réunion" : "Reunjonas",
    "Romania" : "Rumunija",
    "Serbia" : "Serbija",
    "Russian Federation" : "Rusijos Federacija",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Saudo Arabija",
    "Solomon Islands" : "Saliamono salos",
    "Seychelles" : "Seišelių salos",
    "Sudan" : "Sudanas",
    "Sweden" : "Švedija",
    "Singapore" : "Singapūras",
    "Saint Helena, Ascension and Tristan da Cunha" : "Šventosios Elenos, Dangun Žengimo ir Tristanas da Kunja salos",
    "Slovenia" : "Slovėnija",
    "Svalbard and Jan Mayen" : " Svalbard ir Jan Majen salos",
    "Slovakia" : "Slovakija",
    "Sierra Leone" : "Siera Leonė",
    "San Marino" : "San Marinas",
    "Senegal" : "Senegalas",
    "Somalia" : "Somalis",
    "Suriname" : "Surinamas",
    "South Sudan" : "Pietų Sudanas",
    "Sao Tome and Principe" : "San Tomė ir Prinsipė",
    "El Salvador" : "Salvadoras",
    "Sint Maarten (Dutch part)" : "Sint Maartenas (nyderlandų dalis)",
    "Syrian Arab Republic" : "Sirijos Arabų Respublika",
    "Eswatini" : "Esvatinis",
    "Turks and Caicos Islands" : "Terkso ir Kaikoso salos",
    "Chad" : "Čadas",
    "French Southern Territories" : "Prancūzijos Pietų teritorijos",
    "Togo" : "Togas",
    "Thailand" : "Tailandas",
    "Tajikistan" : "Tadžikistanas",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Rytų Timoras",
    "Turkmenistan" : "Turkmėnistanas",
    "Tunisia" : "Tunisas",
    "Tonga" : "Tongas",
    "Turkey" : "Turkija",
    "Trinidad and Tobago" : "Trinidadas ir Tobagas",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taivanas, Kinijos provincija",
    "Tanzania, United Republic of" : "Tanzanijos Jungtinė Respublika",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Jungtinių Valstijų nuošalios mažosios salos",
    "United States of America" : "Jungtinės Amerikos Valstijos",
    "Uruguay" : "Urugvajus",
    "Uzbekistan" : "Uzbekistanas",
    "Holy See" : "Šventasis Sostas",
    "Saint Vincent and the Grenadines" : "Sent Vinsentas ir Grenadinai",
    "Venezuela, Bolivarian Republic of" : "Venesuela, Bolivaro Respublika",
    "Virgin Islands, British" : "Mergelių Salos (Britų)",
    "Virgin Islands, U.S." : "Mergelių Salos (JAV)",
    "Viet Nam" : "Vietnamas",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Volisas ir Futūna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemenas",
    "Mayotte" : "Majotas",
    "South Africa" : "Pietų Afrika",
    "Zambia" : "Zambija",
    "Zimbabwe" : "Zimbabvė",
    "Background blur" : "Fono suliejimas",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Nepavyko patikrinti, ar palaikomas WASM failų įkėlimas. Prašome rankiniu būdu patikrinti, ar jūsų žiniatinklio serveris pateikia `.wasm` failus.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Jūsų žiniatinklio serveris nėra tinkamai sukonfigūruotas „.wasm“ failams pateikti. Paprastai tai susiję su „Nginx“ konfigūracijos problema. Kad veiktų fono suliejimo funkcija, reikia pakoreguoti nustatymus, kad būtų pateikiami ir „.wasm“ failai. Palyginkite savo „Nginx“ konfigūraciją su mūsų dokumentacijoje pateikta rekomenduojama konfigūracija.",
    "Talk configuration values" : "„Pokalbių“ konfigūracijos parametrai",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Skambučio trukmės nustatymas palaikomas tik naudojant sistemos „cron“. Įjunkite sistemos „cron“ arba pašalinkite konfigūracijos parametrą `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Mažos „max_call_duration“ reikšmės (šiuo metu nustatyta %d) negali būti priverstinai taikomos dėl techninių apribojimų. Fono užduotis vykdoma tik kas 5 minutes, todėl naudokite savo pačių atsakomybe.",
    "Federation" : "Federacija",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Jei įjungta „Pokalbių Federacija“ funkcija, labai rekomenduojama nustatyti „memcache.locking“ parametrą.",
    "High-performance backend" : "Didelio našumo posistemė",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Nesukonfigūruota didelio našumo sistema – „Nextcloud Pokalbiai“ paleidimas be didelio našumo sistemos pakanka tik labai mažiems skambučiams (daugiausia 2–3 dalyviams). Nustatykite didelio našumo sistemą, kad skambučiai su keliais dalyviais vyktų sklandžiai.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Didelio našumo posistemės režimas „conversation_cluster“ nebenaudojamas ir nebebus palaikomas būsimoje versijoje. Šiuo metu didelio našumo posistemė palaiko tikrąjį klasterizavimą, kurį reikėtų naudoti vietoj jo.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Kelių didelio našumo serverių apibrėžimas nebenaudojamas ir nebebus palaikomas būsimoje versijoje. Vietoj to, apkrovos balansavimo priemonė turėtų būti nustatyta kartu su klasterizuotais signalizacijos serveriais ir sukonfigūruota „Pokalbiai“ nustatymuose.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "Išsaugotas viešasis raktas, skirtas naudojamam %1$s algoritmui, nesutampa su išsaugotu privačiuoju raktu. Vykdykite %2$s komandą, kad išspręstumėte šią problemą.",
    "High-performance backend not configured correctly. Run %s for details." : "Didelio našumo posistemė netinkamai sukonfigūruota. Paleiskite %s, jei norite gauti išsamesnės informacijos.",
    "High-performance backend not configured correctly" : "Didelio našumo posistemė netinkamai sukonfigūruota",
    "Error: Cannot connect to server" : "Klaida: Nepavyksta prisijungti prie serverio",
    "Error: Server did not respond with proper JSON" : "Klaida: serveris neatsakė tinkamu JSON failu",
    "Error: Certificate expired" : "Klaida: Sertifikatas nebegalioja",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Klaida: „Nextcloud“ serverio ir didelio našumo serverio sistemos laikai nesutampa. Įsitikinkite, kad abu serveriai yra prijungti prie laiko serverio, arba sinchronizuokite jų laiką rankiniu būdu.",
    "Could not get version" : "Nepavyko gauti versijos",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Klaida: Veikia versija: {version}; Serverį reikia atnaujinti, kad jis būtų suderinamas su šia „Pokalbiai“ versija",
    "Error: Server responded with: {error}" : "Klaida: Serveris atsakė: {error}",
    "Error: Unknown error occurred" : "Klaida: Įvyko nežinoma klaida",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Įspėjimas: Veikianti versija: {version}; Serveris nepalaiko visų šios „Talk“ versijos funkcijų, trūksta šių funkcijų: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Labai rekomenduojama sukonfigūruoti atminties talpyklą, kai „Nextcloud Pokalbiai“ veikia su didelio našumo serveriu.",
    "Client Push" : "Kliento „push“ funkcija",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Įdiegta kliento „Push“ funkcija pagerina „Pokalbiai“ pranešimų punktualumą.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} nėra įdiegta. Dėl to „Pokalbiai“ pranešimai gali vėluoti.",
    "Recording backend" : "Įrašymo posistemė",
    "Using the recording backend requires a High-performance backend." : "Įrašymo funkcijai reikalinga didelio našumo posistemė.",
    "No recording backend configured" : "Nėra sukonfigūruotos įrašymo posistemės",
    "SIP configuration" : "SIP konfigūracija",
    "Using the SIP functionality requires a High-performance backend." : "Norint naudoti SIP funkciją, reikalinga didelio našumo posistemė.",
    "Assigned Talk phone numbers must not start with + or 0. Please remove or update the following numbers:\n{list}" : "Priskirti „Pokalbiams“ telefono numeriai negali prasidėti pliusu (+) arba nuliu (0). Pašalinkite arba atnaujinkite šiuos numerius:\n{list}",
    "No SIP backend configured" : "Nėra sukonfigūruotos SIP posistemės",
    "Invalid date, date format must be YYYY-MM-DD" : "Netinkama data, datos formatas privalo būti MMMM-mm-dd",
    "Conversation not found" : "Pokalbis nerastas",
    "Path is already shared with this conversation" : "Nuoroda jau buvo pasidalinta šioje pokalbio sesijoje",
    "Chat, video & audio-conferencing using WebRTC" : "Pokalbiai, vaizdo ir garso konferencijos naudojant WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Pokalbiai, vaizdo ir garso konferencijos naudojant „WebRTC“\n\n* 💬 **Pokalbiai** Nextcloud „Pokalbiai“ turi paprastą teksto pokalbių funkciją, leidžiančią bendrinti arba įkelti failus iš Nextcloud „Failai“ programėlės arba vietinio įrenginio ir paminėti kitus dalyvius.\n* 👥 **Privatūs, grupiniai, vieši ir slaptažodžiu apsaugoti skambučiai!** Pakvieskite ką nors, visą grupę arba išsiųskite viešą nuorodą, kad pakviestumėte į skambutį.\n* 🌐 **Federuoti pokalbiai** Bendraukite su kitais „Nextcloud“ vartotojais jų serveriuose\n* 💻 **Ekrano bendrinimas!** Bendrinkite savo ekraną su skambučio dalyviais.\n* 🚀 **Integracija su kitomis „Nextcloud“ programėlėmis**, tokiomis kaip „Failai“, „Kalendorius“, „Vartotojo būsena“, „Skydelis“, „Eigos“, „Žemėlapiai“, „Išmanusis rinkiklis“, „Kontaktai“, „Darbai“ ir daugeliu kitų.\n* 🌉 **Sinchronizavimas su kitais pokalbių sprendimais** Integravus [Matterbridge](https://github.com/42wim/matterbridge/) į „Pokalbiai“, galite lengvai sinchronizuoti daugybę kitų pokalbių sprendimų su Nextcloud „Pokalbiai“ ir atvirkščiai.",
    "Leave call" : "Išeiti iš skambučio",
    "Navigating away from the page will leave the call in {conversation}" : "Išėjus iš puslapio, skambutis bus sustabdytas {conversation}",
    "Stay in call" : "Pasilikti skambutyje",
    "Error occurred when getting the conversation information" : "Įvykusi klaida gaunant pokalbio informaciją",
    "Duplicate session" : "Dubliuoti sesiją",
    "Discuss this file" : "Aptarkite šį failą",
    "Loading …" : "Įkeliama…",
    "Share this file with others to discuss it" : "Bendrinti šį failą su kitais, norint jį aptarti",
    "Join conversation" : "Prisijungti prie pokalbio",
    "Share this file" : "Bendrinti šį failą",
    "Error occurred when joining the conversation" : "Prisijungiant prie pokalbio įvyko klaida",
    "Open in full application" : "Atidaryti visoje programėlėje",
    "This conversation is password-protected." : "Šis pokalbis yra apsaugotas slaptažodžiu.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Iš jūsų IP adreso užfiksuota keletas neteisingų slaptažodžio įvedimo bandymų. Dėl to kitas jūsų bandymas bus atidėtas 30 sekundžių.",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "Password" : "Slaptažodis",
    "Submit" : "Pateikti",
    "Error requesting the password." : "Klaida prašant slaptažodžio.",
    "Request password" : "Prašyti slaptažodžio",
    "This conversation has ended" : "Šis pokalbis pasibaigė",
    "Close Talk sidebar" : "Užverti „Pokalbių“ šoninę juostą",
    "Open Talk sidebar" : "Atverti „Pokalbiai“ šoninę juostą",
    "Everyone" : "Visi",
    "Users and moderators" : "Naudotojai ir moderatoriai",
    "Moderators only" : "Tik moderatoriai",
    "Disable calls" : "Išjungti skambučius",
    "Save changes" : "Įrašyti pakeitimus",
    "Saving …" : "Įrašoma …",
    "Saved!" : "Įrašyta!",
    "Limit to groups" : "Apriboti iki grupių",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Pasirinkus bent vieną grupę, pokalbiuose gali dalyvauti tik išvardytų grupių žmonės.",
    "Guests can still join public conversations." : "Svečiai vis tiek gali prisijungti prie viešų pokalbių.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Vartotojai, kurie nebegali naudotis „Pokalbiais“, vis tiek bus įtraukti į ankstesnių pokalbių dalyvių sąrašą, o jų pokalbių žinutės taip pat bus išsaugotos.",
    "Limit using Talk" : "Riboti naudojimąsi „Pokalbiai“",
    "Limit creating a public and group conversation" : "Riboti viešų ir grupinių pokalbių kūrimą",
    "Limit creating conversations" : "Riboti pokalbių kūrimą",
    "Limit starting a call" : "Riboti skambučio pradėjimą",
    "Limit starting calls" : "Riboti skambučių pradėjimą",
    "When a call has started, everyone with access to the conversation can join the call." : "Prasidėjus skambučiui, visi, turintys prieigą prie pokalbio, gali prisijungti prie skambučio.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Šiame serveryje įdiegti šie robotai. Dokumentacijoje galite rasti išsamią informaciją, kaip sukurti {linkstart1} savo botą {linkend}, arba {linkstart2} botų sąrašą {linkend}, kuriuos reikia įjungti serveryje.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Šiame serveryje nėra įdiegtų botų. Dokumentacijoje galite rasti išsamią informaciją, kaip sukurti {linkstart1} savo botą {linkend}, arba {linkstart2} botų sąrašą {linkend}, kuriuos reikia įjungti serveryje.",
    "Description is not provided" : "Aprašas nepateiktas",
    "Locked for moderators" : "Užrakinta moderatoriams",
    "Enabled" : "Įjungta",
    "Disabled" : "Išjungta",
    "Bots settings" : "Botų nustatymai",
    "State" : "Būsena",
    "Name" : "Vardas",
    "Last error" : "Paskutinė klaida",
    "Total errors count" : "Bendras klaidų skaičius",
    "Find more bots" : "Raskite daugiau botų",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Patikimus serverius galima konfigūruoti {linkstart} bendrinimo nustatymų puslapyje {linkend}.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Susieję pokalbiai ir skambučiai jau veikia. Priedų tvarkymas bus įtrauktas į būsimą versiją.",
    "Enable Federation in Talk app" : "Įjungti federaciją „Pokalbių“ programėlėje",
    "Permissions" : "Leidimai",
    "Allow users to be invited to federated conversations" : "Leisti vartotojams būti pakviestiems į federacinius pokalbius",
    "Allow users to invite federated users into conversation" : "Leisti vartotojams kviesti federacinius vartotojus į pokalbį",
    "Only allow to federate with trusted servers" : "Leisti jungtis federacinius būdu tik su patikimais serveriais",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Jei pasirinkta bent viena grupė, tik į sąrašą įtrauktų grupių nariai gali kviesti federacinius vartotojus į pokalbius.",
    "Groups allowed to invite federated users" : "Grupės, kurioms leidžiama kviesti federacinius vartotojus",
    "Select groups …" : "Pasirinkti grupes...",
    "All messages" : "Visos žinutės",
    "@-mentions only" : "Tik @ paminėjimai",
    "Off" : "Išjungta",
    "General settings" : "Bendri nustatymai",
    "Default notification settings" : "Numatytieji pranešimų nustatymai",
    "Default group notification" : "Numatytasis grupės pranešimas",
    "Default group notification for new groups" : "Numatytasis pranešimas apie naujas grupes",
    "Integration into other apps" : "Integracija į kitas programėles",
    "Allow conversations on files" : "Leisti pokalbius failuose",
    "Allow conversations on public shares for files" : "Leisti pokalbius viešai bendrinamuose failuose",
    "End-to-end encrypted calls" : "Skambučiai naudojant ištisinį šifravimą",
    "Enable encryption" : "Įjungti šifravimą",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Skambučiams su ištisiniu šifravimu, naudojant sukonfigūruotą SIP tiltą, reikalinga naujesnė „Aukšto našumo posistemės“ ir SIP tilto versija.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Mobilieji klientai šiuo metu nepalaiko skambučių su ištisiniu šifravimu.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Paspaudus mygtuką viršuje, formoje pateikta informacija bus nusiųsta į „Struktur AG“ serverius. Daugiau informacijos rasite {linkstart} svetainėje spreed.eu {linkend}.",
    "Pending" : "Laukiantis",
    "Error" : "Klaida",
    "Blocked" : "Blokuota",
    "Active" : "Aktyvi",
    "Expired" : "Nebegalioja",
    "Never" : "Niekada",
    "The trial could not be requested. Please try again later." : "Bandomosios versijos užsisakyti nepavyko. Prašome pabandyti vėliau.",
    "The account could not be deleted. Please try again later." : "Nepavyko ištrinti paskyros. Vėliau bandykite dar kartą.",
    "Hosted High-performance backend" : "Teikėjo valdoma didelio našumo posistemė",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Mūsų partneris „Struktur AG“ teikia paslaugą, leidžiančią užsisakyti nuotolinį signalinį serverį. Tam tereikia užpildyti žemiau pateiktą formą, ir jūsų „Nextcloud“ pateiks užklausą. Kai serveris bus jums sukonfigūruotas, prisijungimo duomenys bus įrašyti automatiškai. Tai pakeis esamus signalinio serverio nustatymus.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Jei jūsų aukšto našumo posistemės paskyroje yra įjungtos STUN ir (arba) TURN funkcijos, nustatymai bus atitinkamai atnaujinti.",
    "URL of this Nextcloud instance" : "Šio Nextcloud egzemplioriaus URL",
    "Full name of the user requesting the trial" : "Pilnas vartotojo, prašančio suteikti bandomąją versiją, vardas ir pavardė",
    "Email of the user" : "Naudotojo el. paštas",
    "Language" : "Kalba",
    "Country" : "Šalis",
    "Request signaling server trial" : "Prašymas išbandyti signalinį serverį",
    "You can see the current status of your hosted signaling server in the following table." : "Toliau pateiktoje lentelėje galite pamatyti savo nuotolinio signalinio serverio dabartinę būseną.",
    "Status" : "Būsena",
    "Created at" : "Sukurta",
    "Expires at" : "Baigia galioti",
    "Limits" : "Limitai",
    "STUN included" : "Įtrauktas STUN",
    "Yes" : "Taip",
    "No" : "Ne",
    "TURN included" : "Įtrauktas TURN",
    "Delete the signaling server account" : "Ištrinti signalinio serverio paskyrą",
    "_%n user_::_%n users_" : ["%n vartotojas","%n vartotojai","%n vartotojų","%n vartotojas"],
    "Installed version: {version}" : "Įdiegta versija: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Galite įdiegti „Matterbridge“, kad susietumėte Nextcloud „Pokalbiai“ su kitomis paslaugomis. Daugiau informacijos rasite jų {linkstart1} „GitHub“ puslapyje{linkend}. Programėlės atsisiuntimas ir diegimas gali užtrukti. Jei užtrunka, įdiekite ją rankiniu būdu iš {linkstart2} „Nextcloud Programėlių Parduotuvės“ {linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "„Matterbridge“ dvejetainis failas turi neteisingus leidimus. Įsitikinkite, kad „Matterbridge“ dvejetainis failas priklauso teisingam vartotojui ir gali būti vykdomas. Jį galima rasti aplanke „/…/nextcloud/apps/talk_matterbridge/bin/“.",
    "Matterbridge binary was not found or couldn't be executed." : "„Matterbridge“ dvejetainis failas nerastas arba jo nepavyko vykdyti.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Taip pat galite rankiniu būdu nustatyti kelią iki „Matterbridge“ dvejetainio failo per konfigūraciją. Daugiau informacijos rasite {linkstart} „Matterbridge“ integracijos dokumentacijoje {linkend}.",
    "Downloading …" : "Atsisiunčiama…",
    "Install Talk Matterbridge" : "Įdiekite „Pokalbių Matterbridge“",
    "An error occurred while installing the Matterbridge app" : "Įdiegiant „Matterbridge“ programėlę įvyko klaida",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Diegiant „Pokalbių Matterbridge“ įvyko klaida. Įdiekite ją rankiniu būdu.",
    "Failed to execute Matterbridge binary." : "Nepavyko paleisti „Matterbridge“ vykdomojo failo.",
    "Matterbridge integration" : "„Matterbridge“ integracija",
    "Enable Matterbridge integration" : "Įjungti „Matterbridge“ integraciją",
    "Status: Checking connection" : "Būsena: Tikrinamas ryšys",
    "OK: Running version: {version}" : "Gerai: Veikianti versija: {version}",
    "Error: Server seems to be a Signaling server" : "Klaida: Atrodo, kad serveris yra signalinis serveris",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Klaida: „Nextcloud“ serverio ir įrašymo serverio sistemos laikai nesutampa. Įsitikinkite, kad abu serveriai yra prijungti prie laiko serverio, arba sinchronizuokite jų laiką rankiniu būdu.",
    "Recording backend URL" : "Įrašymo posistemės URL",
    "Validate SSL certificate" : "Patikrinti SSL sertifikatą",
    "Delete this server" : "Ištrinti šį serverį",
    "Test this server" : "Išbandyti šį serverį",
    "Disabled for all calls" : "Išjungta visiems skambučiams",
    "Enabled for all calls" : "Įjungta visiems skambučiams",
    "Configurable on conversation level by moderators" : "Moderatoriai gali konfigūruoti pokalbių lygmeniu",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "PHP parametrai „upload_max_filesize“ arba „post_max_size“ leidžia įkelti tik failus, kurių dydis ned augiau kaip {maxUpload}.",
    "Recording backend settings saved" : "Išsaugoti įrašymo posistemės nustatymai",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "Moderatoriai galės įjungti sutikimo reikalavimą pokalbio lygmeniu. Prieš prisijungiant prie kiekvieno šio pokalbio skambučio, iš kiekvieno dalyvio bus reikalaujama duoti sutikimą, kad pokalbis būtų įrašomas.",
    "The consent to be recorded will be required for each participant before joining every call." : "Prieš prisijungiant prie kiekvieno pokalbio, iš kiekvieno dalyvio bus reikalaujama sutikimo, kad pokalbis būtų įrašomas.",
    "The consent to be recorded is not required." : "Sutikimo įrašymui nereikia.",
    "Recording backend configuration is only possible with a High-performance backend." : "Įrašymo serverio konfigūracija įmanoma tik naudojant didelio našumo posistemę.",
    "Add a new recording backend server" : "Pridėti naują įrašymo posistemės serverį",
    "Shared secret" : "Bendrinama paslaptis",
    "Recording consent" : "Sutikimas dėl įrašymo",
    "Recording transcription" : "Įrašymo transkripcija",
    "Automatically transcribe call recordings with a transcription provider" : "Automatiškai transkribuokite skambučių įrašus naudodami transkripcijos paslaugų teikėją",
    "Automatically summarize call recordings with transcription and summary providers" : "Automatiškai apibendrinkite skambučių įrašus naudodami transkripcijos ir santraukų teikėjus",
    "SIP configuration saved!" : "SIP konfigūracija įrašyta!",
    "SIP configuration is only possible with a High-performance backend." : "SIP konfigūracija įmanoma tik naudojant didelio našumo posistemę.",
    "Enable SIP Dial-out option" : "Įjungti SIP išeinančiojo skambinimo parinktį",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "Signalinį serverį reikia atnaujinti, kad būtų palaikoma SIP skambinimo iš telefono funkcija.",
    "Do not show SIP Dial-out caller number" : "Nerodyti SIP skambinančiojo numerio",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "Skambinantysis turėtų matyti, kad skambina iš „nežinomo“ arba „paslėpto“ numerio",
    "Dial-out number" : "Išeinančio skambučio numeris",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "E164 formatuotas numeris, naudojamas kaip atsarginis skambinančiojo numeris išeinantiems skambučiams",
    "Dial-out prefix" : "Išeinančių skambučių prefiksas",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Priešais išeinančių skambučių vartotojo numerį nurodytas prefiksas (numatyta reikšmė – „+“)",
    "Restrict SIP configuration" : "Apriboti SIP konfigūraciją",
    "Enable SIP configuration" : "Įjungti SIP konfigūraciją",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Tik šių grupių vartotojai gali įjungti SIP pokalbiuose, kuriuos jie moderuoja",
    "Phone number (Country)" : "Telefono numeris (Šalis)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Ši informacija siunčiama kvietimo laiškuose ir rodoma šoninėje juostoje visiems dalyviams.",
    "Nextcloud base URL" : "Nextcloud bazinis URL",
    "Talk Backend URL" : "„Pokalbių“ posistemės URL",
    "WebSocket URL" : "WebSocket URL",
    "Available features" : "Prieinamos ypatybės",
    "Error: Websocket connection failed" : "Klaida: nepavyko užmegzti „WebSocket“ ryšio",
    "Error code" : "Klaidos kodas",
    "Error message" : "Klaidos pranešimas",
    "Error: Websocket connection failed. Check browser console" : "Klaida: nepavyko užmegzti „WebSocket“ ryšio. Patikrinkite naršyklės konsolę",
    "High-performance backend URL" : "Didelio našumo posistemės URL",
    "Missing High-performance backend warning hidden" : "Trūkstamas didelio našumo posistemės įspėjimas paslėptas",
    "High-performance backend settings saved" : "Išsaugoti didelio našumo posistemės nustatymai",
    "Nextcloud Talk setup not complete" : "Nextcloud „Pokalbių“ nustatymas nebaigtas",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Atkreipkite dėmesį, kad pokalbiuose, kuriuose dalyvauja daugiau nei 2 dalyviai ir nėra naudojama didelio našumo posistemė, dalyviai greičiausiai susidurs su ryšio sutrikimais, o tai sukels didelę apkrovą dalyvaujančiuose įrenginiuose.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Įdiekite didelio našumo posistemę, kad skambučiai su keliais dalyviais vyktų sklandžiai.",
    "Nextcloud portal" : "Nextcloud portalas",
    "Quick installation guide" : "Trumpas diegimo vadovas",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "Skambučiams ir pokalbiams, kuriuose dalyvauja keli dalyviai, reikalinga didelio našumo posistemė. Be šios posistemės visi dalyviai turės atskirai įkelti savo vaizdo įrašą kiekvienam kitam dalyviui, o tai greičiausiai sukels ryšio sutrikimų ir didelę apkrovą dalyvaujančiuose įrenginiuose.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Naudojant Nextcloud „Pokalbius“ su didelio našumo posisteme, labai rekomenduojama įdiegti paskirstytąją talpyklą.",
    "Add High-performance backend server" : "Pridėti didelio našumo posistemės serverį",
    "Warn about connectivity issues in calls with more than 2 participants" : "Įspėti apie ryšio sutrikimus pokalbiuose, kuriuose dalyvauja daugiau nei 2 dalyviai",
    "STUN server URL" : "STUN serverio URL",
    "The server address is invalid" : "Serverio adresas yra neteisingas",
    "STUN settings saved" : "STUN nustatymai įrašyti",
    "STUN servers" : "STUN serveriai",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN serveris naudojamas siekiant nustatyti už maršrutizatoriaus esančių dalyvių viešuosius IP adresus.",
    "Add a new STUN server" : "Pridėti naują STUN serverį",
    "{schema} scheme must be used with a domain" : "{schema} schema turi būti naudojama su domenu",
    "{option1} and {option2}" : "{option1} ir {option2}",
    "{option} only" : "tik {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "Gerai: TURN serveris grąžino sėkmingus ICE kandidatus",
    "Error: No working ICE candidates returned by the TURN server" : "Klaida: TURN serveris negrąžino veikiančių ICE kandidatų",
    "Testing whether the TURN server returns ICE candidates" : "Tikrinama, ar TURN serveris grąžina ICE kandidatus",
    "TURN server schemes" : "TURN serverio schemos",
    "TURN server URL" : "TURN serverio URL",
    "TURN server secret" : "TURN serverio paslaptis",
    "TURN server protocols" : "TURN serverio protokolai",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "TURN serveris naudojamas perduoti per tarpinį serverį duomenų srautą iš dalyvių, esančių už ugniasienės. Jei atskiri dalyviai negali prisijungti prie kitų, greičiausiai reikalingas TURN serveris. Sąrankos instrukcijas rasite {linkstart} šioje dokumentacijoje {linkend}.",
    "TURN settings saved" : "TURN nustatymai įrašyti",
    "TURN servers" : "TURN serveriai",
    "Add a new TURN server" : "Pridėti naują TURN serverį",
    "Failed" : "Nepavyko",
    "OK" : "Gerai",
    "Checking …" : "Tikrinama…",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Nepavyko: „WebAssembly“ yra išjungta arba nepalaikoma šioje naršyklėje. Norėdami atlikti patikrinimą, įjunkite „WebAssembly“ arba naudokite naršyklę, kuri jį palaiko.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Nepavyko: žiniatinklio serveris netinkamai grąžino failus „.wasm“ ir „.tflite“. Patikrinkite skyrių „Sistemos reikalavimai“ „Pokalbių“ dokumentacijoje.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "Gerai: žiniatinklio serveris tinkamai grąžino failus „.wasm“ ir „.tflite“.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Atrodo, kad PHP ir Apache konfigūracijos nesuderinamos. Atkreipkite dėmesį, kad PHP galima naudoti tik su MPM_PREFORK moduliu, o PHP-FPM – tik su MPM_EVENT moduliu.",
    "Web server setup checks" : "Žiniatinklio serverio sąrankos patikrinimai",
    "Files required for virtual background can be loaded" : "Galima įkelti virtualiam fonui reikalingus failus",
    "Federated user" : "\"Federuotas\" vartotojas",
    "Assign participants to rooms" : "Priskirkite dalyvius į kambarius",
    "Configure breakout rooms" : "Konfigūruokite grupinio darbo kambarius",
    "Number of breakout rooms" : "Grupinio darbo kambarių skaičius",
    "You can create from 1 to 20 breakout rooms." : "Galite sukurti nuo 1 iki 20 grupinio darbo kambarių.",
    "Assignment method" : "Priskyrimo metodas",
    "Automatically assign participants" : "Automatiškai priskirti dalyvius",
    "Manually assign participants" : "Rankiniu būdu priskirti dalyvius",
    "Allow participants to choose" : "Leisti dalyviams pasirinkti",
    "Create rooms" : "Sukurti kambarius",
    "Confirm" : "Patvirtinti",
    "Create breakout rooms" : "Sukurti grupinio darbo kambarius",
    "Reset" : "Atstatyti",
    "Delete breakout rooms" : "Ištrinti grupinio darbo kambarius",
    "Room {roomNumber}" : "Kambarys {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Dabartiniai grupinio darbo kambariai ir nustatymai bus prarasti",
    "Cancel" : "Atsisakyti",
    "Unassigned participants" : "Nepriskirti dalyviai",
    "Back" : "Atgal",
    "Assign" : "Priskirti",
    "Add participant \"{user}\"" : "Pridėti dalyvį „{user}“",
    "Now" : "Dabar",
    "Invalid calendar selected" : "Pasirinktas netinkamas kalendorius",
    "Invalid start time selected" : "Pasirinktas netinkamas pradžios laikas",
    "Invalid end time selected" : "Pasirinktas netinkamas pabaigos laikas",
    "Unknown error occurred" : "Įvyko nežinoma klaida",
    "Sending no invitations" : "Kvietimų nesiunčiama",
    "{participant0} will receive an invitation" : "{participant0} gaus kvietimą",
    "{participant0} and {participant1} will receive invitations" : "{participant0} ir {participant1} gaus kvietimus",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} ir %n gaus kvietimus","{participant0}, {participant1} ir %n kiti gaus kvietimus","{participant0}, {participant1} ir %n kitų gaus kvietimus","{participant0}, {participant1} ir %n kitų gaus kvietimus"],
    "Invite {user}" : "Pakviesti {user}",
    "Invite all users and emails in this conversation" : "Pakviesti visus šio pokalbio vartotojus ir el. pašto adresus",
    "Meeting created" : "Susitikimas sukurtas",
    "Upcoming meetings" : "Artėjantys susitikimai",
    "No upcoming meetings" : "Artėjančių susitikimų nėra",
    "Schedule a meeting" : "Suplanuoti susitikimą",
    "Meeting title" : "Susitikimo pavadinimas",
    "From" : "Nuo",
    "To" : "Kam",
    "Calendar" : "Kalendorius",
    "Attendees" : "Dalyviai",
    "No other participants to send invitations to." : "Nėra kitų dalyvių, kuriems būtų galima siųsti kvietimus.",
    "Add attendees" : "Pridėti dalyvius",
    "Save" : "Įrašyti",
    "Search participants" : "Ieškoti dalyvių",
    "No results" : "Rezultatų nėra",
    "Done" : "Atlikta",
    "Disable live transcription" : "Išjungti transkripciją realiuoju laiku",
    "Enable live transcription (generated by AI)" : "Įjungti tiesioginį transkribavimą (sukurta dirbtinio intelekto)",
    "Enable live transcription (Live transcriptions app is not installed)" : "Įjunkite transkripciją realiuoju laiku (programėlė „Transkripcijos realiuoju laiku“ nėra įdiegta)",
    "Disable live translation" : "Išjungti vertimą realiuoju laiku",
    "Enable live translation (generated by AI)" : "Įjungti vertimą realiuoju laiku (sukurtą dirbtinio intelekto)",
    "Original language" : "Originalo kalba",
    "Live translations app is not installed" : "Vertimo realiuoju laiku programėlė neįdiegta",
    "Original language: {languageName}" : "Originalo kalba: {languageName}",
    "Translated language" : "Išversta kalba",
    "Translated language: {languageName}" : "Išversta kalba: {languageName}",
    "Exit full screen (F)" : "Išeiti iš viso ekrano (F)",
    "Full screen (F)" : "Visas ekranas (F)",
    "Speaker view" : "Garsiakalbio vaizdas",
    "Grid view" : "Tinklelio rodinys",
    "Error when trying to load the available live transcription languages" : "Klaida bandant įkelti galimas transkripcijos realiuoju laiku kalbas",
    "Failed to enable live transcription" : "Nepavyko įjungti transkripcijos realiuoju laiku",
    "Failed to enable live translations" : "Nepavyko įjungti vertimo realiuoju laiku",
    "Failed to disable live translations" : "Nepavyko išjungti vertimo realiuoju laiku",
    "Recording consent is required" : "Būtinas sutikimas įrašyti",
    "This conversation is read-only" : "Šis pokalbis yra tik skaitymui",
    "Conversation not found or not joined" : "Pokalbis nerastas arba prie jo neprisijungta",
    "Lobby is still active and you're not a moderator" : "Laukiamasis vis dar aktyvus, o jūs nesate moderatorius",
    "Connection failed" : "Ryšys patyrė nesėkmę",
    "Reload" : "Įkelti iš naujo",
    "{nickName} raised their hand." : "{nickName} pakėlė ranką.",
    "A participant raised their hand." : "Dalyvis pakėlė ranką.",
    "Collapse stripe" : "Suskleisti juostelę",
    "Expand stripe" : "Išskleisti juostelę",
    "Previous page of videos" : "Ankstesnis vaizdo įrašų puslapio",
    "Next page of videos" : "Kitas vaizdo įrašų puslapis",
    "Connecting …" : "Jungiamasi…",
    "Calling …" : "Skambinama…",
    "Waiting for {user} to join the call" : "Laukiama, kol {user} prisijungs prie skambučio",
    "Waiting for others to join the call …" : "Laukiama, kol kiti prisijungs prie skambučio…",
    "You can invite others in the participant tab of the sidebar" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Galite pakviesti kitus žmonės šoninėje juostoje, dalyvių kortelėje arba bendrindami šią nuorodą, skirtą pakviesti kitus asmenis!",
    "Share this link to invite others!" : "Bendrinkite šią nuorodą, norėdami pakviesti kitus!",
    "Copy link" : "Kopijuoti nuorodą",
    "You are not allowed to enable audio" : "Jums neleidžiama įjungti garsą",
    "No audio. Click to select device" : "Nėra garso. Spustelėkite norėdami pasirinkti įrenginį",
    "Mute audio" : "Nutildyti garsą",
    "Mute audio (M)" : "Nutildyti garsą (M)",
    "Unmute audio" : "Įjungti garsą",
    "Unmute audio (M)" : "Įjungti garsą (M)",
    "None" : "Nėra",
    "Select a microphone" : "Pasirinkti mikrofoną",
    "Select a speaker" : "Pasirinkite garsiakalbį",
    "Microphone settings" : "Mikrofono nustatymai",
    "Check devices" : "Patikrinkite įrenginius",
    "Access to camera was denied" : "Prieiga prie kameros buvo uždrausta",
    "Error while accessing camera: It is likely in use by another program" : "Klaida gaunant prieigą prie kameros: Tikėtina, kad ją naudoja kita programa",
    "Error while accessing camera" : "Klaida gaunant prieigą prie kameros",
    "You have been muted by a moderator" : "Moderatorius jums išjungė garsiakalbį",
    "Hide presenter video" : "Slėpti pranešėjo(-os) vaizdo įrašą",
    "You are not allowed to enable video" : "Jums neleidžiama įjungti vaizdą",
    "No video. Click to select device" : "Nėra vaizdo. Spustelėkite norėdami pasirinkti įrenginį",
    "Disable video" : "Išjungti vaizdą",
    "Disable video (V)" : "Išjungti vaizdą (V)",
    "Enable video" : "Įjungti vaizdą",
    "Enable video (V)" : "Įjungti vaizdą (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą – Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą (V) – Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Įjungti vaizdą. Pirmą kartą įjungiant vaizdą, jūsų ryšys bus trumpam pertrauktas",
    "Select a video device" : "Pasirinkite vaizdo įrenginį",
    "Show presenter" : "Rodyti pranešėją",
    "You" : "Jūs",
    "Mute" : "Nutildyti",
    "Muted" : "Nutildyta",
    "Show screen" : "Rodyti ekraną",
    "Stop following" : "Nustoti sekti",
    "Connection could not be established …" : "Nepavyko užmegzti ryšio…",
    "Connection was lost and could not be re-established …" : "Ryšys nutrūko ir jo nepavyko užmegzti iš naujo…",
    "Connection could not be established. Trying again …" : "Nepavyko užmegzti ryšio. Bandoma dar kartą…",
    "Connection lost. Trying to reconnect …" : "Nutrūko ryšys. Bandoma prisijungti iš naujo…",
    "Connection problems …" : "Ryšio problemos…",
    "Collapse" : "Suskleisti",
    "Expand" : "Išskleisti",
    "You need to be logged in to upload files" : "Norėdami įkelti failus, turite būti prisijungę",
    "Drop your files to upload" : "Tempkite failus, norėdami juos išsiųsti",
    "Conversation messages" : "Pokalbio žinutės",
    "Scroll to bottom" : "Slinkti į apačią",
    "Post message" : "Paskelbti žinutę",
    "Federated conversation" : "Federuotas pokalbis",
    "Public conversation" : "Viešas pokalbis",
    "Favorite" : "Mėgstamas",
    "Banned users" : "Užblokuoti vartotojai",
    "Manage the list of banned users in this conversation." : "Valdykite šio pokalbio užblokuotų vartotojų sąrašą.",
    "Manage bans" : "Tvarkyti blokavimus",
    "No banned users" : "Nėra užblokuotų vartotojų",
    "Banned by:" : "Užblokavo:",
    "Date:" : "Data:",
    "Note:" : "Pastaba:",
    "Hide details" : "Slėpti išsamesnę informaciją",
    "Show details" : "Rodyti išsamiau",
    "Unban" : "Panaikinti blokavimą",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Pavadinimą ir aprašymą galite pakeisti {linkstart} Kalendoriuje ↗. {linkend}",
    "Error while updating conversation name" : "Klaida atnaujinant pokalbio pavadinimą",
    "Error while updating conversation description" : "Klaida atnaujinant pokalbio aprašą",
    "Enter a name for this conversation" : "Įveskite šio pokalbio pavadinimą",
    "Edit conversation name" : "Taisyti pokalbio pavadinimą",
    "Edit conversation description" : "Taisyti pokalbio aprašą",
    "Enter a description for this conversation" : "Įveskite šio pokalbio aprašą",
    "Picture" : "Paveikslėlis",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Šiame pokalbyje galima įjungti šiuos botus. Norėdami įdiegti daugiau botų šiame serveryje, susisiekite su savo administratoriumi.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "Šiame serveryje nėra įdiegtų botų. Kreipkitės į administraciją, jei norite, kad šiame serveryje būtų įdiegti botai.",
    "Disable" : "Išjungti",
    "Enable" : "Aktyvuoti",
    "The bot is not available anymore" : "Botas nebėra prieinamas",
    "Breakout rooms" : "Grupinio darbo kambariai",
    "Manage breakout rooms" : "Tvarkyti grupinio darbo kambarius",
    "Set up breakout rooms for this conversation" : "Sukurkite grupinio darbo kambarius šiam pokalbiui",
    "Please select a valid PNG or JPG file" : "Pasirinkite tinkamą PNG ar JPG failą",
    "Choose your conversation picture" : "Pasirinkite pokalbio paveikslėlį",
    "Choose" : "Pasirinkite",
    "Error setting conversation picture" : "Klaida nustatant pokalbio paveikslėlį",
    "Could not set the conversation picture: {error}" : "Nepavyko nustatyti pokalbio paveikslėlio: {error}",
    "Error cropping conversation picture" : "Klaida apkarpant pokalbio paveikslėlį",
    "Error removing conversation picture" : "Klaida pašalinant pokalbio paveikslėlį",
    "Set emoji as conversation picture" : "Nustatyti emociuką kaip pokalbio paveikslėlį",
    "Set background color for conversation picture" : "Nustatyti pokalbio paveikslėlio fono spalvą",
    "Upload conversation picture" : "Įkelti pokalbio paveikslėlį",
    "Choose conversation picture from files" : "Pasirinkite pokalbio paveikslėlį iš failų",
    "Remove conversation picture" : "Pašalinti pokalbio paveikslėlį",
    "The file must be a PNG or JPG" : "Failas privalo būti PNG ar JPG tipo",
    "Set picture" : "Nustatyti paveikslėlį",
    "Default permissions modified for {conversationName}" : "Pakeisti {conversationName} numatytieji leidimai ",
    "Could not modify default permissions for {conversationName}" : "Nepavyko pakeisti {conversationName} numatytųjų leidimų ",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Redaguokite numatytus šio pokalbio dalyvių leidimus. Šie nustatymai netaikomi moderatoriams.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Kiekvieną kartą, kai šiame skyriuje keičiami leidimai, anksčiau atskiriems dalyviams suteikti individualūs leidimai bus panaikinti.",
    "All permissions" : "Visi leidimai",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Dalyviai turi teisę pradėti pokalbį, prisijungti prie pokalbio, įjungti garso ir vaizdo perdavimą bei bendrinti ekrano vaizdą.",
    "Participants can use all available features." : "Dalyviai gali naudotis visomis prieinamomis funkcijomis.",
    "Restricted" : "Apribota",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Dalyviai gali prisijungti prie pokalbių, tačiau negali įjungti garso ar vaizdo, taip pat negali bendrinti ekrano vaizdo, kol moderatorius rankiniu būdu nesuteiks jiems leidimų.",
    "Participants get a reduced feature set until a moderator manually grants additional permissions." : "Dalyviai gauna ribotą funkcijų rinkinį, kol moderatorius rankiniu būdu nesuteikia papildomų teisių.",
    "Advanced permissions" : "Išplėstiniai leidimai",
    "Edit permissions" : "Taisyti leidimus",
    "Conversation settings" : "Pokalbio nustatymai",
    "Basic Info" : "Pagrindinė informacija",
    "Personal" : "Asmeniniai",
    "Moderation" : "Moderavimas",
    "Setup overview" : "Sąrankos apžvalga",
    "Live transcription" : "Transkripcija realiuoju laiku",
    "Live transcriptions app is not installed" : "Transkripcijos realiuoju laiku programėlė neįdiegta",
    "Enable live transcription" : "Įjungti transkripciją realiuoju laiku",
    "Breakout Rooms" : "Grupinio darbo kambariai",
    "Matterbridge" : "„Matterbridge“",
    "Bots" : "Botai",
    "Danger zone" : "Pavojinga zona",
    "Archive conversation" : "Archyvuoti pokalbį",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Archyvuoti pokalbiai pagal numatytuosius nustatymus yra paslėpti pokalbių sąraše. Tačiau jie vis tiek bus rodomi, jei ieškosite pokalbio pavadinimo arba atidarysite archyvuotų pokalbių sąrašą.",
    "Do you really want to leave \"{displayName}\"?" : "Ar tikrai norite išeiti iš „{displayName}“?",
    "You can archive this conversation instead." : "Vietoj to galite archyvuoti šį pokalbį.",
    "Leave conversation" : "Išeiti iš pokalbio",
    "You need to promote a new moderator before you can leave the conversation" : "Prieš išeidami iš pokalbio turite paskirti naują moderatorių",
    "Delete conversation" : "Ištrinti pokalbį",
    "Do you really want to delete \"{displayName}\"?" : "Ar tikrai norite ištrinti \"{displayName}\"?",
    "Error while deleting conversation" : "Klaida ištrinant pokalbį",
    "Delete all chat messages" : "Ištrinti visas pokalbių žinutes",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Ar tikrai norite ištrinti visas žinutes, esančias „{displayName}“?",
    "Error while clearing chat history" : "Klaida išvalant pokalbio istoriją",
    "Be careful, these actions cannot be undone." : "Būkite atsargūs, šių veiksmų nebegalėsite atšaukti.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Išėjus iš pokalbio, norint vėl prisijungti prie uždaryto pokalbio, reikia gauti kvietimą. Prie atviro pokalbio galima prisijungti bet kuriuo metu.",
    "Permanently delete this conversation." : "Ištrinti šį pokalbį visam laikui.",
    "Delete chat messages" : "Ištrinti pokalbio žinutes",
    "Permanently delete all the messages in this conversation." : "Visam laikui ištrinti visus šio pokalbio pranešimus.",
    "Custom expiration time" : "Pasirinktinis galiojimo laikas",
    "Message expiration disabled" : "Pranešimo galiojimo laikas išjungtas",
    "Message expiration set: {duration}" : "Pranešimo galiojimo laikas nustatytas: {duration}",
    "Error when trying to set message expiration" : "Klaida bandant nustatyti pranešimo galiojimo laiką",
    "Message expiration" : "Pranešimo galiojimo pabaiga",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Pokalbių žinutės gali būti nebegaliojančios po tam tikro laiko. Pastaba: pokalbyje bendrinami failai nebus ištrinti savininkui, bet nebebus bendrinami pokalbyje.",
    "Set message expiration" : "Nustatyti pranešimo galiojimo laiką",
    "Current message expiration" : "Dabartinio pranešimo galiojimo laikas",
    "Password copied to clipboard" : "Slaptažodis nukopijuotas į iškarpinę",
    "Password could not be copied" : "Nepavyko nukopijuoti slaptažodžio",
    "Guest access" : "Svečio prieiga",
    "Breakout rooms are not allowed in public conversations." : "Viešose diskusijose negalima kurti atskirų grupinio darbo kambarių.",
    "Allow guests to join this conversation via link" : "Leisti svečiams prisijungti prie šio pokalbio per nuorodą",
    "Password protection" : "Apsauga slaptažodžiu",
    "This conversation is password-protected. Guests need password to join" : "Šis pokalbis apsaugotas slaptažodžiu. Svečiams reikia slaptažodžio, kad galėtų prisijungti.",
    "Password protection is needed for public conversations" : "Viešiems pokalbiams reikalinga slaptažodžio apsauga",
    "Set a password" : "Nustatyti slaptažodį",
    "Change password" : "Keisti slaptažodį",
    "Enter new password" : "Įvesti naują slaptažodį",
    "Save password" : "Įrašyti slaptažodį",
    "Copy password" : "Kopijuoti slaptažodį",
    "Guests are allowed to join this conversation via link" : "Svečiams leidžiama prisijungti prie šio pokalbio per nuorodą",
    "Guests are not allowed to join this conversation" : "Svečiams neleidžiama prisijungti prie šio pokalbio",
    "Resend invitations" : "Siųsti pakvietimus iš naujo",
    "This conversation is open to both registered users and users created with the Guests app" : "Šis pokalbis atviras tiek registruotiems vartotojams, tiek vartotojams, sukurtiems naudojant svečių programėlę.",
    "This conversation is open to registered users" : "Šis pokalbis yra atviras registruotiems naudotojams",
    "This conversation is limited to the current participants" : "Šis pokalbis skirtas tik dabartiniams dalyviams",
    "You opened the conversation to both registered users and users created with the Guests app" : "Atidarėte pokalbį tiek registruotiems vartotojams, tiek vartotojams, sukurtiems naudojant svečių programėlę.",
    "Error occurred when opening or limiting the conversation" : "Atidarant arba ribojant pokalbį įvyko klaida",
    "Open conversation to registered users, showing it in search results" : "Atviras pokalbis registruotiems vartotojams, rodomas paieškos rezultatuose",
    "Also open to users created with the Guests app" : "Taip pat prieinama vartotojams, susikūrusiems naudojant svečių programėlę",
    "Open conversation" : "Atverti pokalbį",
    "Set language spoken in calls" : "Nustatyti pokalbiuose naudojamą kalbą",
    "Languages could not be loaded" : "Nepavyko įkelti kalbų",
    "Loading languages …" : "Įkeliamos kalbos …",
    "Invalid language" : "Neteisinga kalba",
    "Default language (English)" : "Numatomoji kalba (anglų)",
    "Default live transcription language set" : "Numatytasis transkripcijos realiuoju laiku kalbos rinkinys",
    "Live transcription language set: {languageName}" : "Transkripcijos realiuoju laiku kalbos rinkinys: {languageName}",
    "Error when trying to set live transcription language" : "Klaida bandant nustatyti transkripcijos realiuoju laiku kalbą",
    "Start time: {date}" : "Pradžios laikas: {date}",
    "Start time has been updated" : "Pradžios laikas atnaujintas",
    "Error occurred while updating start time" : "Atnaujinant pradžios laiką, įvyko klaida",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Įjungus laukiamąjį, iš vykstančio skambučio bus pašalinti ne moderatoriai.",
    "Enable lobby, restricting the conversation to moderators" : "Įjungti laukiamąjį, apribojant pokalbį tik moderatoriams",
    "Meeting start time" : "Susitikimo pradžios laikas",
    "Start time (optional)" : "Pradžios laikas (nebūtinas)",
    "Import email participants" : "Importuoti el. pašto dalyvius",
    "You can import a list of email participants from a CSV file." : "Galite importuoti el. pašto dalyvių sąrašą iš CSV failo.",
    "Poll drafts" : "Apklausos projektai",
    "Browse poll drafts" : "Peržiūrėti apklausų projektus",
    "Error occurred when locking the conversation" : "Užrakinant pokalbį, įvyko klaida",
    "Error occurred when unlocking the conversation" : "Atrakinant pokalbį, įvyko klaida",
    "Lock conversation" : "Užrakinti pokalbį",
    "This will also terminate the ongoing call." : "Tai taip pat nutrauks vykstantį pokalbį.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Užrakinkite pokalbį, kad niekas negalėtų skelbti žinučių ar pradėti skambučių",
    "Edit" : "Redaguoti",
    "More information" : "Daugiau informacijos",
    "Delete" : "Ištrinti",
    "Add new bridged channel to current conversation" : "Pridėti naują sujungtą kanalą prie dabartinio pokalbio",
    "unknown state" : "nežinoma būsena",
    "running" : "vykdoma",
    "not running, check Matterbridge log" : "neveikia, patikrinkite „Matterbridge“ žurnalą",
    "not running" : "neveikia",
    "Bridge saved" : "Sąsaja išsaugota",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Naudodami „Matterbridge“ galite sujungti kanalus iš įvairių momentinių pranešimų sistemų.",
    "More info on Matterbridge" : "Daugiau informacijos apie „Matterbridge“",
    "Messaging systems" : "Pranešimų sistemos",
    "Enable bridge" : "Įjungti sąsają",
    "Show Matterbridge log" : "Rodyti „Matterbridge“ žurnalą",
    "Log content" : "Žurnalo turinys",
    "Only moderators are allowed to mention @all" : "Tik moderatoriai gali minėti @all",
    "All participants are allowed to mention @all" : "Visiems dalyviams leidžiama paminėti @all",
    "Participants are now allowed to mention @all." : "Dalyviai dabar gali paminėti @all.",
    "Mentioning @all has been limited to moderators." : "Galimybė paminėti @all buvo apribota iki moderatorių.",
    "Allow participants to mention @all" : "Leisti dalyviams paminėti @all",
    "Mention permissions" : "Paminėti leidimus",
    "Notifications" : "Pranešimai",
    "Notify about calls in this conversation" : "Pranešti apie skambučius šiame pokalbyje",
    "Important conversation" : "Svarbus pokalbis",
    "\"Do not disturb\" user status is ignored for important conversations" : "Svarbių pokalbių metu vartotojo būsena „Netrukdyti“ ignoruojama",
    "Sensitive conversation" : "Jautrus pokalbis",
    "Message preview will be disabled in conversation list and notifications" : "Pokalbių sąraše ir pranešimuose bus išjungtas pranešimų peržiūros režimas",
    "Recording consent is required for calls in this conversation" : "Šio pokalbio skambučiams įrašyti reikalingas sutikimas",
    "Recording consent is not required for calls in this conversation" : "Šio pokalbio skambučiams įrašymo sutikimas nereikalingas.",
    "Recording consent requirement was updated" : "Atnaujintas įrašo sutikimo reikalavimas",
    "Error occurred while updating recording consent" : "Atnaujinant įrašymo sutikimą įvyko klaida",
    "Recording Consent" : "Sutikimas dėl įrašymo",
    "Recording consent cannot be changed once a call or breakout session has started." : "Sutikimo įrašyti negalima pakeisti prasidėjus skambučiui ar pokalbiui mažomis grupėmis.",
    "Require recording consent before joining call in this conversation" : "Prieš prisijungiant prie šio pokalbio, reikia gauti sutikimą įrašyti pokalbį",
    "Recording consent is required for all calls" : "Visiems skambučiams reikalingas įrašymo sutikimas",
    "SIP dial-in is now possible without PIN requirement" : "SIP skambinimo funkcija dabar galima be PIN kodo",
    "SIP dial-in is now enabled" : "Dabar įjungtas prisijungimas per SIP",
    "SIP dial-in is now disabled" : "SIP prisijungimas dabar išjungtas",
    "Error occurred when enabling SIP dial-in" : "Įjungiant SIP skambinimo funkciją įvyko klaida",
    "Error occurred when disabling SIP dial-in" : "Išjungiant SIP rinkimą įvyko klaida",
    "Phone and SIP dial-in" : "Skambinimas telefonu ir per SIP",
    "Enable phone and SIP dial-in" : "Įjungti skambinimą telefonu ir SIP",
    "Allow to dial-in without a PIN" : "Leisti prisijungti be PIN kodo",
    "Ongoing" : "Tebevykstantis",
    "{dayPrefix} {dateTime}" : "{dayPrefix} {dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n žmogus priėmė","%n žmonės priėmė","%n žmonių priėmė","%n žmonių priėmė"],
    "_%n person declined_::_%n people declined_" : ["%n žmogus atmetė","%n žmonės atmetė","%n žmonių atmetė","%n žmonių atmetė"],
    "_and %n other attachment_::_and %n other attachments_" : ["ir %n kitas priedas","ir %n kiti priedai","ir %n kitų priedų","ir %n kitų priedų"],
    "With {displayName}" : "Su {displayName}",
    "In {conversation}" : "{conversation}",
    "View attachment" : "Žiūrėti priedą",
    "Join" : "Prisijungti",
    "View conversation" : "Žiūrėti pokalbį",
    "View event on Calendar" : "Žiūrėti įvykį kalendoriuje",
    "Error while creating the conversation" : "Klaida kuriant pokalbį",
    "Hello, {displayName}" : "Sveiki, {displayName}",
    "Start meeting now" : "Pradėti susitikimą dabar",
    "Give your meeting a title" : "Pavadinkite savo susitikimą",
    "Create and copy link" : "Sukurti ir nukopijuoti nuorodą",
    "Create a new conversation" : "Sukurti naują pokalbį",
    "Join open conversations" : "Prisijungti prie atvirų pokalbių",
    "Call a phone number" : "Paskambinti telefono numeriu",
    "Scroll backward" : "Slinkti atgal",
    "Scroll forward" : "Slinkti į priekį",
    "Schedule meetings" : "Suplanuoti susitikimus",
    "You don't have any upcoming meetings" : "Neturite jokių būsimų susitikimų",
    "Calendar events with a conversation link as the location are shown here" : "Čia rodomi kalendoriaus įvykiai, kurių vieta nurodyta kaip pokalbio nuoroda.",
    "Open calendar" : "Atverti kalendorių",
    "Unread mentions" : "Neskaityti paminėjimai",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Žinutės, kuriose buvote paminėtas, bus rodomos čia. Galite paminėti žmones įvesdami @ ir jų vardus.",
    "Upcoming reminders" : "Artėjantys priminimai",
    "Message reminders" : "Pranešimų priminimai",
    "Set a reminder on a message to be notified" : "Nustatykite priminimą apie pranešimą, kad gautumėte pranešimą",
    "Start a group conversation" : "Pradėti grupinį pokalbį",
    "Create conversation" : "Sukurti pokalbį",
    "Enter your name" : "Įveskite savo vardą",
    "Submit name and join" : "Pateikti vardą ir prisijungti",
    "Do you already have an account?" : "Ar jau turite paskyra?",
    "Log in" : "Prisijungti",
    "Error while verifying uploaded file" : "Klaida tikrinant įkeltą failą",
    "Uploaded file is verified" : "Įkeltas failas patvirtintas",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "Turinio formatas yra kableliais atskirtos reikšmės (CSV):<br/> – Antraštės eilutė yra privaloma ir turi sutapti<samp> su „vardas“, „el. paštas“ arba tiesiog <samp>„el. paštas“</samp><br/> – Po vieną įrašą eilutėje (pvz., „John Doe“, „john@example.tld“<samp>)",
    "Participants added successfully" : "Dalyviai sėkmingai pridėti",
    "Error while adding participants" : "Pridedant dalyvius įvyko klaida",
    "Import a file" : "Importuoti failą",
    "Browse" : "Naršyti",
    "Verifying uploaded file …" : "Pridedant dalyvius įvyko klaida",
    "This might take a moment" : "Tai gali šiek tiek užtrukti",
    "Send invitations" : "Siųsti kvietimus",
    "_%n invalid email_::_%n invalid emails_" : ["%n neteisingas el. pašto adresas","%n neteisingi el. pašto adresai","%n neteisingų el. pašto adresų","%n neteisingų el. pašto adresų"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n el. laiškas jau importuotas arba yra pasikartojantis","%n el. laiškai jau importuoti arba yra pasikartojantys","%n el. laiškų jau importuota arba yra pasikartojantys","%n el. laiškų jau importuota arba yra pasikartojantys"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n kvietimą galima siųsti","%n kvietimus galima siųsti","%n kvietimų galima siųsti","%n kvietimų galima siųsti"],
    "An error occurred while calling a phone number" : "Skambinant telefono numeriu įvyko klaida",
    "Phone number could not be called: {error}" : "Nepavyko paskambinti telefono numeriu: {error}",
    "Phone number could not be called" : "Nepavyko paskambinti telefono numeriu",
    "Search participants or phone numbers" : "Ieškoti dalyvių arba telefono numerių",
    "Creating the conversation …" : "Kuriamas pokalbis…",
    "Mark as read" : "Žymėti kaip skaitytą",
    "Mark as unread" : "Žymėti kaip neskaitytą",
    "Remove from favorites" : "Šalinti iš mėgstamų",
    "Add to favorites" : "Pridėti į mėgstamus",
    "Unarchive conversation" : "Atkurti pokalbio archyvą",
    "Ignore \"Do not disturb\"" : "Ignoruoti „Netrukdyti“",
    "You need to promote a new moderator before you can leave the conversation." : "Prieš išeidami iš pokalbio, turite paaukštinti naują moderatorių.",
    "New tag" : "Nauja žyma",
    "Tag name" : "Žymos pavadinimas",
    "Conversation actions" : "Pokalbio veiksmai",
    "Tags" : "Žymos",
    "Notify about calls" : "Pranešti apie skambučius",
    "Hide message text" : "Slėpti pranešimo tekstą",
    "Remove all tags" : "Pašalinti visas žymes",
    "Rename tag" : "Pašalinti žymę",
    "Delete tag" : "Ištrinti žymą",
    "Do you really want to delete \"{name}\"? Conversations with this tag will be moved to \"Other\"." : "Ar tikrai norite ištrinti „{name}“? Pokalbiai su šia žyma bus perkelti į „Kita“.",
    "Move up" : "Pakelti",
    "Move down" : "Nuleisti",
    "Pending invitations" : "Laukiantys kvietimai",
    "Join conversations from other servers" : "Prisijunkite prie pokalbių iš kitų serverių",
    "From {user} at {remoteServer}" : "Nuo {user} iš {remoteServer}",
    "Decline invitation" : "Atmesti pakvietimą",
    "Accept invitation" : "Priimti pakvietimą",
    "No pending invitations" : "Nėra laukiančių kvietimų",
    "Home" : "Pagrindinis",
    "Unread" : "Neskaityta",
    "Mentions" : "Paminėjimai",
    "Meetings" : "Susitikimai",
    "Sort conversations" : "Rūšiuoti pokalbius",
    "By recent activity" : "Pagal pastarąją veiklą",
    "Alphabetically" : "Pagal abėcėlę",
    "Do not group by type" : "Negrupuoti pagal tipą",
    "Show private ones first" : "Pirmiausia parodykite privačius",
    "Show group ones first" : "Pirmiausia parodykite grupinius",
    "No followed threads" : "Nėra sekamų gijų",
    "No matches found" : "Nerasta jokių atitikmenų",
    "No conversations found" : "Pokalbių nerasta",
    "You have no archived conversations." : "Neturite archyvuotų pokalbių.",
    "Subscribe to an existing thread or start your own." : "Prenumeruokite esamą temą arba pradėkite savo.",
    "You have no unread mentions." : "Neturite neskaitytų paminėjimų.",
    "You have no unread messages." : "Jūs neturite neskaitytų žinučių.",
    "An error occurred while performing the search" : "Atliekant paiešką, įvyko klaida",
    "Conversation list" : "Pokalbių sąrašas",
    "Filter conversations by" : "Filtruoti pokalbius pagal",
    "Unread messages" : "Neskaitytos žinutės",
    "Meeting conversations" : "Susitikimų pokalbiai",
    "Clear filters" : "Išvalyti filtrus",
    "New personal note" : "Naujas asmeninis užrašas",
    "SIP backend is not installed" : "SIP posistemė neįdiegta",
    "Back to conversations" : "Atgal į pokalbius",
    "Threads" : "Temos",
    "Archived conversations" : "Archyvuoti pokalbiai",
    "Clear filter" : "Išvalyti filtrą",
    "Show more threads" : "Rodyti daugiau temų",
    "App settings" : "Programėlės nustatymai",
    "Users" : "Vartotojai",
    "Groups" : "Grupės",
    "Teams" : "Komandos",
    "Federated users" : "„Federuoti\" vartotojai",
    "New private conversation" : "Naujas privatus pokalbis",
    "Other sources" : "Kiti šaltiniai",
    "Open conversations" : "Atviri pokalbiai",
    "No search results" : "Nėra paieškos rezultatų",
    "Users, groups and teams" : "Naudotojai, grupės ir komandos",
    "Users and groups" : "Naudotojai ir grupės",
    "Users and teams" : "Naudotojai ir komandos",
    "Groups and teams" : "Grupės ir komandos",
    "New group conversation" : "Naujas grupės pokalbis",
    "The meeting will start soon" : "Susitikimas netrukus prasidės",
    "This meeting is scheduled for {startTime}" : "Šis susitikimas yra suplanuotas {startTime}",
    "You are currently waiting in the lobby" : "Šiuo metu laukiate laukiamąjame",
    "Enable noise suppression" : "Įjungti triukšmo slopinimą",
    "Reduce background noises for better voice quality" : "Sumažinkite foninį triukšmą, kad balso kokybė būtų geresnė",
    "Basic" : "Pagrindinis",
    "Advanced" : "Išplėstiniai",
    "Enable echo cancellation" : "Įjungti aido panaikinimą",
    "Minimize echo effect from own surrounding" : "Sumažinkite aido efektą savo aplinkoje",
    "Enable auto gain control" : "Įgalinti automatinį stiprinimo valdymą",
    "Dynamically adjust microphone volume for consistent level" : "Dinamiškai reguliuokite mikrofono garsumą, kad lygis būtų pastovus",
    "Select microphone" : "Pasirinkti mikrofoną",
    "No microphone available" : "Nėra prieinamo mikrofono",
    "Select speaker" : "Pasirinkite garsiakalbį",
    "No speaker available" : "Garsiakalbis nepasiekiamas",
    "Select camera" : "Pasirinkti kamerą",
    "No camera available" : "Nėra prieinamos kameros",
    "Select a device" : "Pasirinkti įrenginį",
    "Playing …" : "Atkuriama…",
    "Test speakers" : "Išbandyti garsiakalbius",
    "Test" : "Testuoti",
    "Devices" : "Įrenginiai",
    "Backgrounds" : "Fonai",
    "No audio" : "Nėra jokio garso",
    "No camera" : "Nėra kameros",
    "Display video as you will see it (mirrored)" : "Rodyti vaizdo įrašą taip, kaip jį matysite (veidrodinį)",
    "Display video as others will see it" : "Rodyti vaizdo įrašą taip, kaip jį matys kiti",
    "Calls are not supported in your browser" : "Jūsų naršyklėje skambučiai yra nepalaikomi",
    "Access to microphone is only possible with HTTPS" : "Prieiga prie mikrofono yra įmanoma tik naudojant HTTPS",
    "Access to microphone was denied" : "Prieiga prie mikrofono buvo uždrausta",
    "Error while accessing microphone" : "Klaida gaunant prieigą prie mikrofono",
    "Access to camera is only possible with HTTPS" : "Prieiga prie kameros yra įmanoma tik naudojant HTTPS",
    "The call is being recorded." : "Skambutis įrašomas.",
    "The call might be recorded." : "Skambutis gali būti įrašomas.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "Įraše gali būti jūsų balsas, vaizdo įrašas iš kameros ir ekrano bendrinimo vaizdas. Prieš prisijungiant prie skambučio, reikalingas jūsų sutikimas.",
    "Give consent to the recording of this call" : "Duoti sutikimą įrašyti šį pokalbį",
    "You can only join a voice room via a call." : "Prie bendravimo kambario galite prisijungti tik per skambutį.",
    "Show more info" : "Rodyti daugiau informacijos",
    "Audio is not available" : "Garso nėra",
    "Video is not available" : "Vaizdo nėra",
    "Start recording immediately with the call" : "Pradėkite įrašymą iš karto skambinant",
    "Recording backend is not installed" : "Įrašymo posistemė neįdiegta",
    "Notify all participants about this call" : "Pranešti visiems dalyviams apie šį skambutį",
    "Apply settings" : "Taikyti nustatymus",
    "Select virtual office background" : "Pasirinkite virtualaus biuro foną",
    "Select virtual home background" : "Pasirinkite virtualių namų foną",
    "Select virtual abstract background" : "Pasirinkite virtualų abstraktų foną",
    "Select virtual beach background" : "Pasirinkite virtualų paplūdimio foną",
    "Select virtual park background" : "Pasirinkite virtualaus parko foną",
    "Select virtual theater background" : "Pasirinkite virtualaus teatro foną",
    "Select virtual library background" : "Pasirinkite virtualios bibliotekos foną",
    "Select virtual space station background" : "Pasirinkite virtualios kosminės stoties foną",
    "Error while uploading the file" : "Įkeliant failą įvyko klaida",
    "Select a file" : "Pasirinkti failą",
    "Invalid path selected" : "Pasirinktas neteisingas kelias",
    "Select virtual background from file {fileName}" : "Pasirinkite virtualų foną iš {fileName} failo",
    "Blur" : "Suliejimas",
    "Upload" : "Įkelti",
    "Files" : "Failai",
    "(editing)" : "(redagavimas)",
    "(edited)" : "(redaguota)",
    "The message has expired or has been deleted" : "Žinutė nebegalioja arba buvo ištrinta",
    "Cancel quote" : "Atšaukti citatą",
    "24 hours" : "24 valandos",
    "7 days" : "7 dienos",
    "30 days" : "30 dienų",
    "Until unpin" : "Kol nebus atsegta",
    "Clear reminder – {timeLocale}" : "Išvalyti priminimą - {timeLocale}",
    "Edited by {actor}" : "Redagavo {actor}",
    "Pinned by you" : "Jūs prisgėte",
    "Pinned by {actor}" : "Prisegė {actor}",
    "Until {absoluteDate}" : "Iki {absoluteDate}",
    "Message text copied to clipboard" : "Žinutės tekstas nukopijuotas į iškarpinę",
    "Message text could not be copied" : "Nepavyko nukopijuoti žinutės teksto",
    "Message forwarded to \"Note to self\"" : "Žinutė persiųsta į „Pastaba sau“",
    "Error while forwarding message to \"Note to self\"" : "Klaida persiunčiant pranešimą į „Pastaba sau“",
    "A reminder was successfully removed" : "Priminimas buvo sėkmingai pašalintas",
    "Error occurred when removing a reminder" : "Šalinant priminimą įvyko klaida",
    "A reminder was successfully set at {datetime}" : "Priminimas sėkmingai nustatytas {datetime}",
    "Error occurred when creating a reminder" : "Kuriant priminimą įvyko klaida",
    "Add a reaction to this message" : "Pridėti reakciją į šį pranešimą",
    "Reply" : "Atsakyti",
    "More actions" : "Daugiau veiksmų",
    "Set reminder" : "Nustatyti priminimą",
    "Pin message" : "Prisegti pranešimą",
    "Unpin message" : "Atsegti pranešimą",
    "Reply privately" : "Atsakyti privačiai",
    "Edit message" : "Redaguoti laišką",
    "Copy message" : "Kopijuoti pranešimą",
    "Copy message link" : "Kopijuoti žinutės nuorodą",
    "Go to file" : "Pereiti į failą",
    "Download file" : "Atsisiųsti failą",
    "Go to thread" : "Eiti į temą",
    "Edit thread details" : "Redaguoti temos informaciją",
    "Forward message" : "Persiųsti žinutę",
    "Translate" : "Verskite",
    "Set custom reminder" : "Nustatyti tinkintą priminimą",
    "Keep pinned for" : "Laikyti prisegtą",
    "Set custom period" : "Nustatyti tinkintą laikotarpį",
    "Close reactions menu" : "Užverti reakcijų meniu",
    "React with {emoji}" : "Reaguoti naudojant {emoji}",
    "React with another emoji" : "Reaguoti kitu emociuku",
    "Choose a conversation to forward the selected message." : "Pasirinkite pokalbį, kad persiųstumėte pasirinktą pranešimą.",
    "Error while forwarding message" : "Klaida persiunčiant žinutę",
    "The message has been forwarded to {selectedConversationName}" : "Žinutė buvo persiųsta į {selectedConversationName}",
    "Dismiss" : "Atmesti",
    "Go to conversation" : "Eikite į pokalbį",
    "Detect language" : "Aptikti kalbą",
    "The message could not be translated" : "Nepavyko išversti laiško",
    "Translation copied to clipboard" : "Vertimas nukopijuotas į iškarpinę",
    "Translation could not be copied" : "Nepavyko nukopijuoti vertimo",
    "Translate message" : "Versti žinutę",
    "Source language to translate from" : "Pradinė kalba, iš kurios versti",
    "Translate from" : "Versti iš",
    "Target language to translate into" : "Paskirties kalba, į kurią versti",
    "Translate to" : "Versti į",
    "Translating" : "Verčiama",
    "This translation is AI generated and may contain mistakes." : "Šis vertimas yra sugeneruotas dirbtinio intelekto ir gali turėti klaidų.",
    "Copy translated text" : "Kopijuoti išverstą tekstą",
    "Error when scheduling the message" : "Klaida planuojant pranešimą",
    "Reschedule" : "Pakeisti datą",
    "Send now" : "Siųsti dabar",
    "Choose a time" : "Pasirinkite laiką",
    "Send at custom time" : "Siųsti pasirinktu laiku",
    "Will be sent without notification" : "Bus išsiųsta be pranešimo",
    "Message read by everyone who shares their reading status" : "Žinutę perskaitė visi, kurie pasidalijo savo skaitymo būsena",
    "Message sent" : "Žinutė išsiųsta",
    "Sent without notification" : "Nusiųsta be pranešimo",
    "Deleting message" : "Žinutės ištrynimas",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Žinutė sėkmingai ištrinta, bet sukonfigūruotas botas arba „Matterbridge“ ir žinutė jau gali būti išplatinta kitoms paslaugoms",
    "Message deleted successfully" : "Žinutė sėkmingai ištrinta",
    "Message could not be deleted because it is too old" : "Nepavyko ištrinti žinutės, nes ji per sena",
    "Only normal chat messages can be deleted" : "Galima ištrinti tik įprastas pokalbių žinutes",
    "An error occurred while deleting the message" : "Trinant pranešimą įvyko klaida",
    "Pinned" : "Prisegta",
    "Your browser does not support playing audio files" : "Jūsų naršyklė nepalaiko garso įrašo failų atkūrimo",
    "Contact" : "Kontaktas",
    "{stack} in {board}" : "{stack} lentelėje {board}",
    "Deck Card" : "Darbų kortelė",
    "Remove {fileName}" : "Šalinti {fileName}",
    "Open this location in OpenStreetMap" : "Atidaryti šią vietą „OpenStreetMap“ žemėlapyje",
    "_%n reply_::_%n replies_" : ["%n atsakymas","%n atsakymai","%n atsakymų","%n atsakymų"],
    "Sending message" : "Siunčiamas pranešimas",
    "Failed to send the message. Click to try again" : "Nepavyko išsiųsti pranešimo. Spustelėkite, kad bandytumėte dar kartą.",
    "Not enough free space to upload file" : "Nepakanka laisvos vietos failui įkelti",
    "You cannot send messages to this conversation at the moment" : "Šiuo metu negalite siųsti žinučių į šį pokalbį",
    "Could not update the message" : "Nepavyko atnaujinti pranešimo",
    "Reply to thread \"{threadTitle}\"" : "Atsakyti į temą „{threadTitle}“",
    "_You voted • %n vote_::_You voted • %n votes_" : ["Jūs balsavote • %n balsas","Jūs balsavote • %n balsai","Jūs balsavote • %n balsų","Jūs balsavote • %n balsų"],
    "You voted" : "Jūs balsavote",
    "_Click to vote • %n vote_::_Click to vote • %n votes_" : ["Spustelėkite, kad balsuotumėte • %n balsas","Spustelėkite, kad balsuotumėte • %n balsai","Spustelėkite, kad balsuotumėte • %n balsų","Spustelėkite, kad balsuotumėte • %n balsų"],
    "Click to vote" : "Spustelėkite, kad balsuotumėte",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Apklausos projektas • %n pasirinkimas","Apklausos projektas • %n pasirinkimai","Apklausos projektas • %n pasirinkimų","Apklausos projektas • %n pasirinkimų"],
    "_%n vote_::_%n votes_" : ["%n balsas","%n balsai","%n balsų","%n balsas"],
    "Edit poll draft" : "Redaguoti apklausos projektą",
    "Delete poll draft" : "Ištrinti apklausos juodraštį",
    "Open poll" : "Pradėti apklausą",
    "Closed poll" : "Uždaryta apklausa",
    "See results" : "Rodyti rezultatus",
    "Reactions" : "Reakcijos",
    "No permission to post reactions in this conversation" : "Šiame pokalbyje nėra leidimo skelbti reakcijų",
    "and {participant}" : "ir {participant}",
    "_and %n other participant_::_and %n other participants_" : ["ir dar %n dalyvis","ir dar %n dalyviai","ir dar %n dalyvių","ir dar %n dalyvis"],
    "Show all reactions" : "Rodyti visas reakcijas",
    "Add more reactions" : "Pridėti daugiau reakcijų",
    "Show or collapse system messages" : "Rodyti arba sutraukti sistemos pranešimus",
    "No messages" : "Nėra laiškų",
    "All messages have expired or have been deleted." : "Visos žinutės nebegalioja arba buvo ištrintos.",
    "Generate summary with AI" : "Sukurkite santrauką naudodami AI",
    "{author} (pinned by you)" : "{author} (jūs prisegėte)",
    "{author} (pinned by {actor})" : "{author} (prisegė {actor})",
    "Unpin" : "Atsegti",
    "Cancel search" : "Atsisakyti paieškos",
    "Add a phone number" : "Pridėti telefono numerį",
    "Error: A password is required to create the conversation." : "Klaida: norint sukurti pokalbį, reikia įvesti slaptažodį.",
    "All set, the conversation \"{conversationName}\" was created." : "Viskas paruošta, pokalbis „{conversationName}“ buvo sukurtas.",
    "Create a new group conversation" : "Sukurti naują grupės pokalbį",
    "Add participants" : "Pridėti dalyvius",
    "Maximum length exceeded ({maxlength} characters)" : "Viršytas maksimalus ilgis ({maxlength} simbolių)",
    "Conversation type" : "Pokalbio tipas",
    "Default parameters are:" : "Numatytieji parametrai yra:",
    "These settings can be changed once the conversation is created." : "Šiuos nustatymus galima pakeisti, kai pokalbis jau sukurtas.",
    "Conversation visibility" : "Pokalbio matomumas",
    "Allow guests to join via link" : "Leisti svečiams prisijungti per nuorodą",
    "Enter password" : "Įvesti slaptažodį",
    "This conversation has been locked" : "Šis pokalbis užrakintas",
    "No permission to post messages in this conversation" : "Neturite leidimo rašyti pranešimų šioje diskusijoje",
    "Joining conversation …" : "Prisijungiama prie pokalbio…",
    "Write a message without notification" : "Parašykite žinutę be pranešimo",
    "Create a thread silently" : "Sukurti temą tyliai",
    "Create a thread" : "Sukurti temą",
    "Send message silently" : "Siųsti žinutę tyliai",
    "Send message" : "Siųsti žinutę",
    "Send without notification" : "Siųsti be pranešimo",
    "The participant will not be notified about new messages" : "Dalyvis nebus informuojamas apie naujus pranešimus",
    "Participants will not be notified about new messages" : "Dalyviai nebus informuojami apie naujus pranešimus",
    "Message will be sent {datetimeString}" : "Pranešimas bus išsiųstas {datetimeString}",
    "Thread title is required" : "Reikalingas temos pavadinimas",
    "Message text is required" : "Būtinas žinutės tekstas",
    "The message could not be edited" : "Nepavyko redaguoti žinutės",
    "File to share" : "Failas, kurį bendrinti",
    "File upload is not available in this conversation" : "Šiame pokalbyje failų įkėlimas negalimas",
    "Message was successfully scheduled" : "Pranešimas sėkmingai suplanuotas",
    "Add emoji" : "Pridėti emocuką",
    "Adding a mention will only notify users who did not read the message." : "Pridėjus paminėjimą, bus informuoti tik tie vartotojai, kurie neskaitė žinutės.",
    "Thread title" : "Temos antraštė",
    "Send later" : "Siųsti vėliau",
    "Show scheduled messages" : "Rodyti suplanuotas žinutes",
    "Cancel editing" : "Atšaukti redagavimą",
    "Schedule message" : "Nustatyti pranešimo siuntimo laiką",
    "{user} is out of office and might not respond." : "{user} yra išvykęs(-usi) ir gali neatsakyti",
    "Absence period: {startDate} - {endDate}" : "Nebuvimo laikotarpis: {startDate} - {endDate}",
    "Replacement:" : "Pakeitimas:",
    "Share from {nextcloud}" : "Bendrinimas iš {nextcloud}",
    "Share from Files" : "Bendrinti iš failų",
    "Share files to the conversation" : "Bendrinkite failus pokalbyje",
    "Upload from device" : "Įkelti iš įrenginio",
    "Create new poll" : "Sukurti naują apklausą",
    "Smart picker" : "„Išmanusis rinkiklis“",
    "Record voice message" : "Įrašyti balso pranešimą",
    "End recording and send" : "Baigti įrašymą ir išsiųsti",
    "Dismiss recording" : "Atšaukti įrašymą",
    "Access to the microphone was denied" : "Prieiga prie mikrofono buvo uždrausta",
    "Microphone either not available or disabled in settings" : "Mikrofonas arba neprieinamas, arba išjungtas nustatymuose",
    "Error while recording audio" : "Klaida įrašant garso įrašą",
    "Voice message {time} ({conversation})" : "Balso žinutė {time} ({conversation})",
    "Generating summary of unread messages …" : "Neskaitytų pranešimų santraukos sukūrimas...",
    "Summary is AI generated and might contain mistakes" : "Santrauka sukurta dirbtinio intelekto pagalba ir joje gali būti klaidų",
    "Error occurred during a summary generation" : "Generuojant santrauką įvyko klaida",
    "New file" : "Naujas failas",
    "Blank" : "Tuščia",
    "Error while creating file" : "Klaida kuriant failą",
    "Create and share a new file" : "Sukurti ir bendrinti naują failą",
    "Name of the new file" : "Naujo failo pavadinimas",
    "Create file" : "Sukurti failą",
    "Someone is typing …" : "Kažkas rašo…",
    "{user1} is typing …" : "{user1} rašo…",
    "{user1} and {user2} are typing …" : "{user1} ir {user2} rašo…",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} ir {user3} rašo…",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} ir dar %n kitas rašo…","{user1}, {user2}, {user3} ir dar %n kiti rašo…","{user1}, {user2}, {user3} ir dar %n kitų rašo…","{user1}, {user2}, {user3} ir dar %n kitų rašo…"],
    "Add more files" : "Pridėti daugiau failų",
    "Send" : "Siųsti",
    "In this conversation <strong>{user}</strong> can:" : "Šiame pokalbyje <strong>{user}</strong> gali:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Redaguoti numatytuosius dalyvių leidimus <strong>{conversationName}</strong>",
    "Start a call" : "Pradėti skambutį",
    "Skip the lobby" : "Praleisti laukiamąjį",
    "Can post messages" : "Gali skelbti pranešimus",
    "Can post messages and reactions" : "Gali skelbti pranešimus ir reakcijas",
    "Can add reactions" : "Galima pridėti reakcijas",
    "Enable the microphone" : "Įjungti mikrofoną",
    "Enable the camera" : "Įjungti kamerą",
    "Share the screen" : "Bendrinti ekraną",
    "Update permissions" : "Atnaujinti leidimus",
    "Updating permissions" : "Leidimų atnaujinimas",
    "No poll drafts" : "Nėra apklausų projektų",
    "There is no poll drafts yet saved for this conversation" : "Šio pokalbio metu dar nėra išsaugotų apklausų projektų",
    "Create poll in {name}" : "Sukurti apklausą {name}",
    "Create poll" : "Sukurti apklausą",
    "Error while importing poll" : "Klaida importuojant apklausą",
    "Question" : "Klausimas",
    "Ask a question" : "Užduoti klausimą",
    "Import draft from file" : "Importuoti projektą iš failo",
    "Answers" : "Atsakymai",
    "Answer {option}" : "Atsakymas {option}",
    "Delete poll option" : "Ištrinti apklausos variantą",
    "Add answer" : "Pridėti atsakymą",
    "Settings" : "Nustatymai",
    "Anonymous poll" : "Anoniminė apklausa",
    "Multiple answers" : "Keli atsakymai",
    "Save as draft" : "Išsaugoti kaip juodraštį",
    "Export draft to file" : "Eksportuoti juodraštį į failą",
    "_Final results • %n vote_::_Final results • %n votes_" : ["Galutiniai rezultatai • %n balsas","Galutiniai rezultatai • %n balsai","Galutiniai rezultatai • %n balsų","Galutiniai rezultatai • %n balsų"],
    "_%n vote • Your vote is anonymous_::_%n votes • Your vote is anonymous_" : ["%n balsas • Jūsų balsas yra anoniminis","%n balsai • Jūsų balsas yra anoniminis","%n balsų • Jūsų balsas yra anoniminis","%n balsų • Jūsų balsas yra anoniminis"],
    "Your vote is anonymous" : "Jūsų balsas yra anoniminis",
    "You voted for this option" : "Jūs balsavote už šį variantą",
    "End poll" : "Baigti apklausą",
    "Change your vote" : "Keisti savo balsą",
    "Withdraw vote" : "Atšaukti balsą",
    "Results" : "Rezultatai",
    "Download as spreadsheet" : "Atsisiųsti kaip skaičiuoklę",
    "Download as CSV" : "Atsisiųsti kaip CSV",
    "Voted participants" : "Balsavo dalyviai",
    "Send a message to \"{roomName}\"" : "Siųsti žinutę „{roomName}“",
    "Hide list of participants" : "Slėpti dalyvių sąrašą",
    "Show list of participants" : "Rodyti dalyvių sąrašą",
    "Assistance requested in {roomName}" : "Paprašyta pagalbos {roomName}",
    "The message was sent to \"{roomName}\"" : "Žinutė buvo išsiųsta adresu „{roomName}“",
    "Dismiss request for assistance" : "Atšaukti prašymą suteikti pagalbą",
    "Send message to room" : "Siųsti žinutę į kambarį",
    "Back to main room" : "Atgal į pagrindinį kambarį",
    "Back to your room" : "Grįžti į savo kambarį",
    "Message all rooms" : "Siųsti pranešimą į visus kambarius",
    "Start session" : "Pradėti sesiją",
    "Start a call before you start a breakout room session" : "Pradėkite skambutį prieš pradėdami grupinio darbo sesiją",
    "Stop session" : "Sustabdyti sesiją",
    "The message was sent to all breakout rooms" : "Žinutė buvo išsiųsta į visus grupinio darbo kambarius",
    "Send a message to all breakout rooms" : "Siųsti žinutę į visus grupinio darbo kambarius",
    "Breakout rooms are not started" : "Grupinio darbo kambariai nepradėti",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Skambučiai be didelio našumo posistemės gali sukelti ryšio problemų ir didelę įrenginių apkrovą. {linkstart} Sužinokite daugiau {linkend}",
    "Talk setup incomplete" : "„Pokalbių“ nustatymas nebaigtas",
    "Disable lobby" : "Išjungti laukimo salę",
    "Settings for participant \"{user}\"" : "Dalyvio „{user}“ nustatymai",
    "Participant \"{user}\"" : "Dalyvis „{user}“",
    "moderator" : "moderatorius",
    "bot" : "botas",
    "guest" : "svečias",
    "Ringing …" : "Skambina…",
    "Call rejected" : "Skambutis atmestas",
    "{time} talking …" : "{time} kalbama…",
    "{time} talking time" : " pokalbio trukmė {time}",
    "Raised their hand" : "Pakėlė ranką",
    "Joined with video" : "Prisijungta su vaizdu",
    "Joined via phone" : "Prisijungta telefonu",
    "Joined with audio" : "Prisijungta su garsu",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "Tekstas turi būti ne ilgesnis kaip {maxLength} simbolių arba trumpesnis. Jūsų dabartinis tekstas yra {charactersCount} simbolių ilgio.Teksto ilgis turi būti ne didesnis kaip ženklai. Jūsų dabartinis tekstas yra ženklai ilgio.",
    "Remove group and members" : "Šalinti grupę ir narius",
    "Remove team and members" : "Šalinti komandą ir narius",
    "Remove participant" : "Šalinti dalyvį",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Ar tikrai norite pašalinti grupę „{displayName}“ ir jos narius iš šio pokalbio?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Ar tikrai norite pašalinti komandą „{displayName}“ ir jos narius iš šio pokalbio?",
    "Do you really want to remove {displayName} from this conversation?" : "Ar tikrai norite pašalinti {displayName} iš šio pokalbio?",
    "Notification was sent to {displayName}" : "Pranešimas išsiųstas {displayName}",
    "Could not send notification to {displayName}" : "Nepavyko išsiųsti pranešimo {displayName}",
    "Permissions granted to {displayName}" : "Suteikti leidimai {displayName}",
    "Could not modify permissions for {displayName}" : "Nepavyko modifikuoti leidimų, skirtų {displayName}",
    "Permissions removed for {displayName}" : "Leidimai pašalinti {displayName}",
    "Permissions set to default for {displayName}" : "Leidimai {displayName} nustatyti pagal numatytuosius nustatymus",
    "Phone number could not be hung up" : "Nepavyko padėti ragelio telefono numerio",
    "Phone number could not be put on hold" : "Negalima perkelti skambučio į laukimo režimą",
    "Phone number could not be muted" : "Nepavyko išjungti telefono skambučio garso",
    "Phone number could not be unmuted" : "Nepavyko įjungti telefono skambučio garso",
    "DTMF message could not be sent" : "Nepavyko išsiųsti DTMF pranešimo",
    "Phone number copied to clipboard" : "Telefono numeris nukopijuotas į iškarpinę",
    "Phone number could not be copied" : "Nepavyko nukopijuoti telefono numerio",
    "in the lobby" : "laukiamąjame",
    "Dial out phone" : "Išeinantis skambutis",
    "Hang up phone" : "Padėti ragelį",
    "Move back to lobby" : "Grįžti į laukiamąjį",
    "Move to conversation" : "Pereiti prie pokalbio",
    "Dial-in PIN" : "Skambinimo PIN kodas",
    "Demote from moderator" : "Pažeminti iš moderatorių",
    "Promote to moderator" : "Paaukštinti į moderatorius",
    "Resend invitation" : "Siųsti pakvietimą iš naujo",
    "Send call notification" : "Siųsti pranešimą apie skambutį",
    "Dial out phone number" : "Surinkti telefono numerį",
    "Resume call for phone number" : "Tęsti skambutį telefono numeriu",
    "Put phone number on hold" : "Užlaikyti telefono numerį",
    "Unmute phone number" : "Įjungti telefono numerio garsą",
    "Mute phone number" : "Nutildyti telefono numerį",
    "Copy phone number" : "Kopijuoti telefono numerį",
    "Reset custom permissions" : "Atstatyti tinkintus leidimus",
    "Grant all permissions" : "Suteikti visus leidimus",
    "Remove all permissions" : "Šalinti visus leidimus",
    "Also ban from this conversation" : "Taip pat uždrausti dalyvauti šiame pokalbyje",
    "Internal note (reason to ban)" : "Vidinė pastaba (blokavimo priežastis)",
    "Remove" : "Šalinti",
    "Permissions modified for {displayName}" : "Leidimai atnaujinti {displayName}",
    "Add users, groups or teams" : "Pridėti vartotojus, grupes arba komandas",
    "Add users or groups" : "Pridėti vartotojus ar grupes",
    "Add users or teams" : "Pridėti vartotojus arba komandas",
    "Add users" : "Pridėti vartotojus",
    "Add groups or teams" : "Pridėti grupes arba komandas",
    "Add groups" : "Pridėti grupes",
    "Add teams" : "Pridėti komandas",
    "Add other sources" : "Pridėti kitus šaltinius",
    "Add emails" : "Pridėti el. paštus",
    "Integrations" : "Integracijos",
    "Add federated users" : "Pridėti federuotus vartotojus",
    "Searching …" : "Ieškoma…",
    "Search for more users" : "Ieškoti daugiau vartotojų",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Galite ieškoti dalyvių arba juos pridėti pagal vardą, el. paštą arba federuotos debesijos ID“",
    "Search or add participants" : "Ieškoti arba pridėti dalyvius",
    "Invitation was sent to {actorId}" : "Kvietimas buvo išsiųstas {actorId}",
    "An error occurred while adding the participants" : "Pridedant dalyvius įvyko klaida",
    "A new group conversation with selected participant will be created" : "Bus sukurta nauja grupinė pokalbių sesija su pasirinktu dalyviu",
    "Participants" : "Dalyviai",
    "Pinned by a deleted user" : "Prisegė ištrintas vartotojas",
    "Participants ({count})" : "Dalyviai ({count})",
    "Open chat" : "Atverti pokalbį",
    "You have new unread messages in the chat." : "Pokalbyje turite naujų neskaitytų žinučių.",
    "You have been mentioned in the chat." : "Buvote paminėtas pokalbyje.",
    "Search messages" : "Ieškoti žinučių",
    "Chat" : "Pokalbis",
    "Details" : "Išsamiau",
    "Shared items" : "Bendrinami elementai",
    "Search in {name}" : "Ieškoti esančių {name}",
    "Threads in {name}" : "Temos esančios {name}",
    "{actor} in {conversation}" : "{actor} pokalbyje {conversation}",
    "Search messages …" : "Ieškoti žinučių...",
    "Search options" : "Paieškos parinktys",
    "From User" : "Iš vartotojo",
    "Since" : "Nuo tada",
    "Until" : "Iki",
    "No results found" : "Nerasta jokių rezultatų",
    "Load more results" : "Įkelti daugiau rezultatų",
    "Recent threads" : "Naujausios temos",
    "Projects" : "Projektai",
    "No shared items" : "Nėra bendrinamų elementų",
    "Thread notifications" : "Temos pranešimai",
    "Thread actions" : "Temų veiksmai",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Nuoroda į pokalbį",
    "No open conversations found" : "Nerasta jokių atvirų pokalbių",
    "Either there are no open conversations or you joined all of them." : "Arba nėra atvirų pokalbių, arba jūs prie jų visų prisijungėte.",
    "Check spelling or use complete words." : "Patikrinkite rašybą arba rašykite pilnais žodžiais.",
    "Search conversations or users" : "Ieškoti pokalbių ar vartotojų",
    "Select conversation" : "Pasirinkite pokalbį",
    "Number length is not valid" : "Numerio ilgis netinkamas",
    "Region code is not valid" : "Regiono kodas neteisingas",
    "Number length is too short" : "Numerio ilgis per trumpas",
    "Number length is too long" : "Numerio ilgis per didelis",
    "Number is not valid" : "Numeris yra neteisingas",
    "Phone numbers" : "Telefono numeriai",
    "Display name: {name}" : "Rodomas vardas: {name}",
    "Edit display name" : "Redaguoti rodomą vardą",
    "Display name (required)" : "Rodomas vardas (privaloma)",
    "Save name" : "Išsaugoti vardą",
    "I picked message bubbles" : "Išsirinkau žinučių burbulus",
    "I picked the list style" : "Pasirinkau sąrašo stilių",
    "Error while setting personal setting" : "Klaida nustatant asmeninius nustatymus",
    "Error while saving sounds setting" : "Klaida išsaugant garso nustatymus",
    "Compact conversations list" : "Sutrumpintas pokalbių sąrašas",
    "Chat appearance" : "Pokalbio išvaizda",
    "Messages list" : "Žinučių sąrašas",
    "Message bubbles" : "Žinučių burbulai",
    "Play sounds when participants join or leave a call" : "Paleisti garsą, kai dalyviai prisijungia prie pokalbio arba jį palieka",
    "Currently not available on iPhone and iPad due to technical restrictions by the manufacturer" : "Šiuo metu negalima naudoti „iPhone“ ir „iPad“ įrenginiuose dėl gamintojo nustatytų techninių apribojimų",
    "Notification settings" : "Pranešimų nustatymai",
    "Sounds for chat and call notifications" : "Garsai, skirti pokalbių ir skambučių pranešimams",
    "Invalid language ({languageId})" : "Neteisinga kalba ({languageId})",
    "Default language" : "Numatytoji kalba",
    "Default language ({languageName})" : "Numatomoji kalba ({languageName})",
    "Error when trying to load the available live translation languages" : "Klaida bandant įkelti galimas vertimo realiuoju laiku kalbas",
    "Error when trying to set live translation language" : "Klaida bandant nustatyti vertimo realiuoju laiku kalbą",
    "Set language used to show the transcriptions" : "Nustatyti kalbą, kuria rodomos transkripcijos",
    "Select location for attachments" : "Pasirinkti vietą priedams",
    "Error while setting attachment folder" : "Klaida nustatant priedų aplanką",
    "Error while setting read status privacy" : "Klaida nustatant skaitymo būsenos privatumą",
    "Error while setting typing status privacy" : "Klaida nustatant rašymo būsenos privatumą",
    "Error while setting default media state" : "Klaida nustatant numatytąjį medijos būseną",
    "Turn camera and microphone off by default" : "Pagal numatytuosius nustatymus išjungti kamerą ir mikrofoną",
    "Blur camera background by default" : "Pagal numatytuosius nustatymus išblukti kameros foną",
    "Skip device preview before joining a call" : "Prieš prisijungiant prie pokalbio praleisti įrenginio peržiūrą",
    "Camera will be turned off when joining. Always shown if recording consent is required." : "Prisijungus kamera bus išjungta. Rodoma visada, jei reikalingas sutikimas įrašyti.",
    "Appearance & Sounds" : "Išvaizda ir Garsai",
    "Privacy" : "Privatumas",
    "Send read receipts" : "Siųsti skaitymo patvirtinimus",
    "When off, all read statuses will be hidden" : "Kai funkcija išjungta, visi skaitymo statusai bus paslėpti",
    "Share typing status" : "Bendrinti rašymo būseną",
    "When off, all typing indicators will be hidden" : "Kai funkcija išjungta, visi rašymo indikatoriai bus paslėpti",
    "Attachments folder" : "Priedų aplankas",
    "Toggle full screen" : "Perjungti visą ekraną",
    "Return to Home screen" : "Grįžti į Pradžios ekraną",
    "Search" : "Ieškoti",
    "Shortcuts while in a chat" : "Spartieji klavišai dalyvaujant pokalbyje",
    "Focus the chat input" : "Pasirinkti pokalbio rašymo laukelį",
    "Unfocus the chat input to use shortcuts" : "Išeiti iš pokalbio rašymo laukelio, kad veiktų spartieji klavišai",
    "Edit your last message" : "Redaguoti paskutinį pranešimą",
    "Shortcuts while in a call" : "Spartieji klavišai dalyvaujant skambutyje",
    "Camera on and off" : "Įjungti ar išjungti kamerą",
    "Microphone on and off" : "Įjungti ar išjungti mikrofoną",
    "Raise or lower hand" : "Pakelti ar nuleisti ranką",
    "Push to talk or push to mute" : "Paspausk ir kalbėk arba paspausk ir nutildyk",
    "Zoom-in / zoom-out a screen share" : "Padidinti / sumažinti ekrano vaizdą",
    "Mouse wheel" : "Peles ratukas",
    "Start call silently" : "Pradėti skambutį tyliai",
    "Start call" : "Pradėti skambutį",
    "End call" : "Baigti pokalbį",
    "The server was updated, you cannot start or join a call." : "Serveris buvo atnaujintas, todėl negalite pradėti pokalbio ar prie jo prisijungti.",
    "This call has just ended" : "Šis pokalbis ką tik baigėsi",
    "You will be able to join the call only after a moderator starts it." : "Prisijungti prie pokalbio galėsite tik tada, kai jį pradės moderatorius.",
    "End call for everyone" : "Baigti pokalbį visiems",
    "Starting the recording" : "Pradėti įrašymą",
    "Recording" : "Įrašymas",
    "The call has been running for one hour." : "Skambutis vyksta jau valandą.",
    "Cancel recording start" : "Atšaukti įrašymo pradžią",
    "Stop recording" : "Sustabdyti įrašymą",
    "Raise hand" : "Pakelti ranką",
    "Raise hand (R)" : "Pakelti ranką (R)",
    "Lower hand" : "Nuleisti ranką",
    "Lower hand (R)" : "Nuleisti ranką (R)",
    "Send a reaction" : "Siųsti reakciją",
    "React with {reaction}" : "Reaguoti naudojant {reaction}",
    "All tasks done!" : "Visos užduotys atliktos!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} iš %n užduoties","{done} iš %n užduočių","{done} iš %n užduočių","{done} iš %n užduočių"],
    "Add participants to this call" : "Pridėti dalyvius prie šio skambučio",
    "_%n participant in call_::_%n participants in call_" : ["%n dalyvis skambutyje","%n dalyviai skambutyje","%n dalyvių skambutyje","%n dalyvių skambutyje"],
    "Scheduled messages" : "Iš anksto suplanuoti pranešimai",
    "You are not allowed to enable screensharing" : "Jums neleidžiama įjungti ekrano bendrinimo",
    "No screensharing" : "Nėra ekrano bendrinimo",
    "Screensharing options" : "Ekrano bendrinimo parinktys",
    "Enable screensharing" : "Įjungti ekrano bendrinimą",
    "Bad sent video and screen quality." : "Prasta išsiųsto vaizdo ir ekrano kokybė.",
    "Bad sent screen quality." : "Prasta išsiųsto ekrano kokybė.",
    "Bad sent video quality." : "Prasta išsiųsto vaizdo kokybė.",
    "Bad sent audio, video and screen quality." : "Prasta išsiųsto garso, vaizdo ir ekrano kokybė.",
    "Bad sent audio and screen quality." : "Prasta išsiųsto garso ir ekrano kokybė.",
    "Bad sent audio and video quality." : "Prasta išsiųsto garso ir vaizdo kokybė.",
    "Bad sent audio quality." : "Prasta išsiųsto garso kokybė.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Jūsų interneto ryšys arba kompiuteris yra užimti, todėl kiti dalyviai gali nematyti jūsų ekrano. Norėdami išspręsti šią problemą, bandykite išjungti fono suliejimo funkciją arba savo vaizdo transliaciją, kai bendrinate ekraną.",
    "Disable background blur" : "Išjungti fono suliejimą",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Jūsų interneto ryšys arba kompiuteris yra užimti, todėl kiti dalyviai gali nematyti jūsų ekrano. Norėdami išspręsti šią problemą, pabandykite išjungti vaizdo transliaciją, kol bendrinate ekraną.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Jūsų interneto ryšys arba kompiuteris yra užimti, todėl kiti dalyviai gali nematyti jūsų ekrano.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Jūsų interneto ryšys arba kompiuteris yra užimti, todėl kiti dalyviai gali jūsų nematyti.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Jūsų interneto ryšys arba kompiuteris yra perkrautas, todėl kiti dalyviai gali nesuprasti, ką sakote, arba nematyti jūsų. Norėdami pagerinti situaciją, bandykite išjungti fono suliejimo funkciją arba išjungti vaizdo transliaciją, kai bendrinate ekraną.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Jūsų interneto ryšys arba kompiuteris yra užimti, todėl kiti dalyviai gali nesuprasti, ką sakote, ir nematyti jūsų. Norėdami pagerinti situaciją, pabandykite išjungti vaizdo transliaciją, kol bendrinate ekraną.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Jūsų interneto ryšys arba kompiuteris yra užimti, todėl kiti dalyviai gali nesuprasti, ką sakote, ir nematyti jūsų ekrano. Norėdami išspręsti šią problemą, pabandykite išjungti ekrano bendrinimą.",
    "Disable screenshare" : "Išjungti ekrano bendrinimą",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Jūsų interneto ryšys arba kompiuteris yra užimti, todėl kiti dalyviai gali nesuprasti, ką sakote, arba nematyti jūsų. Norėdami pagerinti situaciją, pabandykite išjungti vaizdo fono suliejimo funkciją arba išjungti vaizdo transliaciją.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Jūsų interneto ryšys arba kompiuteris yra užimti, todėl kiti dalyviai gali nesuprasti, ką sakote, arba nematyti jūsų. Norėdami pagerinti situaciją, pabandykite išjungti vaizdo transliaciją.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Jūsų interneto ryšys arba kompiuteris yra užimti, todėl kiti dalyviai gali nesuprasti, ką sakote.",
    "Screen sharing is not supported by your browser." : "Jūsų naršyklė nepalaiko ekrano bendrinimo.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Ekrano bendrinimas reikalauja, kad puslapis būtų įkeltas per HTTPS.",
    "An error occurred while starting screensharing." : "Pradedant ekrano bendrinimą, įvyko klaida.",
    "Select virtual background" : "Pasirinkite virtualų foną",
    "Show your screen" : "Rodyti savo ekraną",
    "Stop screensharing" : "Stabdyti ekrano bendrinimą",
    "Mute others" : "Išjungti kitų garsą",
    "Start recording" : "Pradėti įrašymą",
    "Set up breakout rooms" : "Sukurti grupinio darbo kambarius",
    "Download attendance list" : "Atsisiųsti dalyvių sąrašą",
    "Open Calendar" : "Atverti kalendorių",
    "Remove participant {name}" : "Šalinti dalyvį {name}",
    "Would you like to delete this conversation?" : "Ar norėtumėte ištrinti šį pokalbį?",
    "_This conversation will be automatically deleted for everyone after %n day of inactivity._::_This conversation will be automatically deleted for everyone after %n days of inactivity._" : ["Šis pokalbis bus automatiškai ištrintas visiems po %n dienos neaktyvumo.","Šis pokalbis bus automatiškai ištrintas visiems po %n dienų neaktyvumo.","Šis pokalbis bus automatiškai ištrintas visiems po %n dienų neaktyvumo.","Šis pokalbis bus automatiškai ištrintas visiems po %n dienų neaktyvumo."],
    "Are you sure you want to delete this conversation?" : "Ar tikrai norite ištrinti šį pokalbį?",
    "Delete now" : "Ištrinti dabar",
    "Keep" : "Palikti",
    "Open dialpad" : "Atverti numerio rinkiklį",
    "Select a region" : "Pasirinkti regioną",
    "Local time: {time}" : "Vietinis laikas: {time}",
    "Scheduled {datetime}" : "Numatyta {datetime}",
    "Scheduled for {datetime}" : "Suplanuota {datetime}",
    "Search …" : "Ieškoti…",
    "Message without mention" : "Rašyti be paminėjimo",
    "Mention myself" : "Paminėti save",
    "Mention everyone" : "Paminėti kiekvieną",
    "Select a conversation" : "Pasirinkite pokalbį",
    "Select a mode" : "Pasirinkite režimą",
    "You do not have permissions to access this conversation." : "Jūs neturite leidimų pasiekti šio pokalbio.",
    "Join a different conversation or start a new one." : "Prisijunkite prie kito pokalbio arba pradėkite naują.",
    "The conversation does not exist" : "Pokalbio nėra",
    "Join a conversation or start a new one!" : "Prisijunkite prie pokalbio arba pradėkite naują!",
    "This conversation was opened in another tab. The current server version does not support opening a conversation in multiple tabs." : "Šis pokalbis buvo atidarytas kitame skirtuke. Dabartinė serverio versija nepalaiko pokalbio atidarymo keliuose skirtukuose.",
    "Creating and joining a conversation with \"{userid}\"" : "Pokalbio su „{userid}“ kūrimas ir prisijungimas prie jo",
    "Join a conversation or start a new one" : "Prisijunkite prie pokalbio arba pradėkite naują",
    "Error while joining the conversation" : "Klaida prisijungiant prie pokalbio",
    "Another user" : "Kitas vartotojas",
    "Hey! Are you using the list style or message bubbles?" : "Ei! Ar naudojate sąrašo stilių, ar pranešimų burbulus?",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud vartotojas",
    "User password" : "Naudotojo slaptažodis",
    "Talk conversation" : "„Pokalbių“ pokalbis",
    "Skip TLS verification" : "Praleiskite TLS patvirtinimą",
    "Matrix server URL" : "Matrix serverio URL",
    "User" : "Vartotojas",
    "Matrix channel" : "Matrix kanalas",
    "Mattermost server URL" : "„Mattermost“ serverio URL",
    "Mattermost user" : "„Mattermost“ vartotojas",
    "Team name" : "Komandos pavadinimas",
    "Channel name" : "Kanalo pavadinimas",
    "Rocket.Chat server URL" : "Rocket.Chat serverio URL",
    "User name or email address" : "Naudotojo vardas ar el. pašto adresas",
    "Rocket.Chat channel" : "Rocket.Chat kanalas",
    "Zulip server URL" : "„Zulip“ serverio URL",
    "Bot user name" : "Boto vartotojo vardas",
    "Bot API key" : "Boto API raktas",
    "Zulip channel" : "„Zulip“ kanalas",
    "API token" : "API prieigos raktas",
    "Slack channel" : "Slack kanalas",
    "Server ID or name" : "Serverio ID ar pavadinimas",
    "Channel ID (prefixed with \"ID:\") or name" : "Kanalo ID (su prefiksu „ID:“) arba pavadinimas",
    "Channel" : "Kanalas",
    "Login" : "Prisijungti",
    "Chat ID" : "Pokalbio ID",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC serverio URL (pvz., chat.freenode.net:6667)",
    "Nickname" : "Slapyvardis",
    "Connection password" : "Ryšio slaptažodis",
    "IRC channel" : "IRC kanalas",
    "Channel password" : "Kanalo slaptažodis",
    "NickServ nickname" : "„NickServ“ slapyvardis",
    "NickServ password" : "„NickServ“ slaptažodis",
    "Use TLS" : "Naudoti TLS",
    "Use SASL" : "Naudoti SASL",
    "Tenant ID" : "Nuomotojo ID",
    "Client ID" : "Kliento ID",
    "Team ID" : "Komandos ID",
    "Thread ID" : "Temos ID",
    "XMPP/Jabber server URL" : "XMPP/Jabber serverio URL",
    "MUC server URL" : "MUC serverio URL",
    "Jabber ID" : "Jabber ID",
    "Pinned messages" : "Prisegtos žinutės",
    "Media" : "Medija",
    "Polls" : "Apklausos",
    "Deck cards" : "Darbų kortelės",
    "Voice messages" : "Balso žinutės",
    "Locations" : "Vietos",
    "Call recordings" : "Skambučių įrašai",
    "Audio" : "Garso įrašai",
    "Show all pinned messages" : "Rodyti visas prisegtas žinutes",
    "Show all media" : "Rodyti visą mediją",
    "Show all files" : "Rodyti visus failus",
    "Show all polls" : "Rodyti visas apklausas",
    "Show all deck cards" : "Rodyti visas „Darbų“ korteles",
    "Show all voice messages" : "Rodyti visus balso pranešimus",
    "Show all locations" : "Rodyti visas vietas",
    "Show all call recordings" : "Rodyti visus skambučių įrašus",
    "Show all audio" : "Rodyti visus garso įrašus",
    "Show all other" : "Rodyti visa kita",
    "Follow conversation settings" : "Sekite pokalbio nustatymus",
    "Group" : "Grupė",
    "Team" : "Komanda",
    "You reconnected to the call" : "Jūs vėl prisijungėte prie skambučio",
    "{actor} reconnected to the call" : "{actor} vėl prisijungta prie skambučio",
    "You added {user0} and {user1}" : "Jūs pridėjote {user0} ir {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Jūs pridėjote {user0}, {user1} ir %n dar kitą dalyvį","Jūs pridėjote {user0}, {user1} ir %n dar daugiau dalyvių","Jūs pridėjote {user0}, {user1} ir %n dar daugiau dalyvių","Jūs pridėjote {user0}, {user1} ir %n dar daugiau dalyvių"],
    "An administrator added you and {user0}" : "Administratorius pridėjo jus ir {user0}",
    "{actor} added you and {user0}" : "{actor} pridėjo jus ir {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Administratorius pridėjo jus, {user0} ir %n kitą dalyvį","Administratorius pridėjo jus, {user0} ir %n kitus dalyvius","Administratorius pridėjo jus, {user0} ir %n kitų dalyvių","Administratorius pridėjo jus, {user0} ir %n kitų dalyvių"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} pridėjo jus, {user0} ir %n kitą dalyvį","{actor} pridėjo jus, {user0} ir %n kitus dalyvius","{actor} pridėjo jus, {user0} ir %n kitų dalyvių","{actor} pridėjo jus, {user0} ir %n kitų dalyvių"],
    "An administrator added {user0} and {user1}" : "Administratorius pridėjo {user0} ir {user1}",
    "{actor} added {user0} and {user1}" : "{actor} pridėjo {user0} ir {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Administratorius pridėjo {user0}, {user1} ir %n kitą dalyvį","Administratorius pridėjo {user0}, {user1} ir %n kitus dalyvius","Administratorius pridėjo {user0}, {user1} ir %n kitų dalyvių","Administratorius pridėjo {user0}, {user1} ir %n kitų dalyvių"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} pridėjo {user0}, {user1} ir %n kitą dalyvį","{actor} pridėjo {user0}, {user1} ir %n kitus dalyvius","{actor} pridėjo {user0}, {user1} ir %n kitų dalyvių","{actor} pridėjo {user0}, {user1} ir %n kitų dalyvių"],
    "You removed {user0} and {user1}" : "Jūs pašalinote{user0} ir {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Jūs pašalinote {user0}, {user1} ir %n kitą dalyvį","Jūs pašalinote {user0}, {user1} ir %n kitus dalyvius","Jūs pašalinote {user0}, {user1} ir %n kitų dalyvių","Jūs pašalinote {user0}, {user1} ir %n kitų dalyvių"],
    "An administrator removed you and {user0}" : "Administratorius pašalino jus ir {user0}",
    "{actor} removed you and {user0}" : "{actor} pašalino jus ir {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Administratorius pašalino jus, {user0} ir %n kitą dalyvį","Administratorius pašalino jus, {user0} ir %n kitus dalyvius","Administratorius pašalino jus, {user0} ir %n kitų dalyvių","Administratorius pašalino jus, {user0} ir %n kitų dalyvių"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} pašalino jus, {user0} ir %n kitą dalyvį","{actor} pašalino jus, {user0} ir %n kitus dalyvius","{actor} pašalino jus, {user0} ir %n kitų dalyvių","{actor} pašalino jus, {user0} ir %n kitų dalyvių"],
    "An administrator removed {user0} and {user1}" : "Administratorius pašalino {user0} ir {user1}",
    "{actor} removed {user0} and {user1}" : "{actor} pašalino {user0} ir {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Administratorius pašalino {user0}, {user1} ir %n kitą dalyvį","Administratorius pašalino {user0}, {user1} ir %n kitus dalyvius","Administratorius pašalino {user0}, {user1} ir %n kitų dalyvių","Administratorius pašalino {user0}, {user1} ir %n kitų dalyvių"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} pašalino {user0}, {user1} ir %n kitą dalyvį","{actor} pašalino {user0}, {user1} ir %n kitus dalyvius","{actor} pašalino {user0}, {user1} ir %n kitų dalyvių","{actor} pašalino {user0}, {user1} ir %n kitų dalyvių"],
    "You and {user0} joined the call" : "Jūs ir {user0} prisijungėte prie pokalbio",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Jūs, {user0} ir %n kitas dalyvis prisijungėte prie pokalbio","Jūs, {user0} ir %n kiti dalyviai prisijungėte prie pokalbio","Jūs, {user0} ir %n kitų dalyvių prisijungėte prie pokalbio","Jūs, {user0} ir %n kitų dalyvių prisijungėte prie pokalbio"],
    "{user0} and {user1} joined the call" : "{user0} ir {user1} prisijungė prie skambučio",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} ir %n kitas dalyvis prisijungė prie skambučio","{user0}, {user1} ir %n kiti dalyviai prisijungė prie skambučio","{user0}, {user1} ir %n kitų dalyvių prisijungė prie skambučio","{user0}, {user1} ir %n kitų dalyvių prisijungė prie skambučio"],
    "You and {user0} left the call" : "Jūs ir {user0} išėjote iš pokalbio",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Jūs, {user0} ir %n kitas dalyvis išėjote iš pokalbio","Jūs, {user0} ir %n kiti dalyviai išėjote iš pokalbio","Jūs, {user0} ir %n kitų dalyvių išėjote iš pokalbio","Jūs, {user0} ir %n kitų dalyvių išėjote iš pokalbio"],
    "{user0} and {user1} left the call" : "{user0} ir {user1} išėjo iš pokalbio",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} ir %n kitas dalyvis išėjo iš pokalbio","{user0}, {user1} ir %n kiti dalyviai išėjo iš pokalbio","{user0}, {user1} ir %n kitų dalyvių išėjo iš pokalbio","{user0}, {user1} ir %n kitų dalyvių išėjo iš pokalbio"],
    "You promoted {user0} and {user1} to moderators" : "Jūs {user0} ir {user1} paskyrėte moderatoriais",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Jūs {user0}, {user1} ir %n kitą dalyvį paskyrėte moderatoriais","Jūs {user0}, {user1} ir %n kitus dalyvius paskyrėte moderatoriais","Jūs {user0}, {user1} ir %n kitų dalyvių paskyrėte moderatoriais","Jūs {user0}, {user1} ir %n kitų dalyvių paskyrėte moderatoriais"],
    "An administrator promoted you and {user0} to moderators" : "Administratorius jus ir {user0} paskyrė moderatoriais",
    "{actor} promoted you and {user0} to moderators" : "{actor} paskyrė jus ir {user0} moderatoriais",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Administratorius jus, {user0} ir %n kitą dalyvį paskyrė moderatoriais","Administratorius jus, {user0} ir %n kitus dalyvius paskyrė moderatoriais","Administratorius jus, {user0} ir %n kitų dalyvių paskyrė moderatoriais","Administratorius jus, {user0} ir %n kitų dalyvių paskyrė moderatoriais"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} paskyrė jus, {user0} ir %n kitą dalyvį moderatoriais","{actor} paskyrė jus, {user0} ir %n kitus dalyvius moderatoriais","{actor} paskyrė jus, {user0} ir %n kitų dalyvių moderatoriais","{actor} paskyrė jus, {user0} ir %n kitų dalyvių moderatoriais"],
    "An administrator promoted {user0} and {user1} to moderators" : "Administratorius {user0} ir {user1} paskyrė moderatoriais",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} paskyrė {user0} ir {user1} moderatoriais ",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Administratorius {user0}, {user1} ir %n kitą dalyvį paskyrė moderatoriais","Administratorius {user0}, {user1} ir %n kitus dalyvius paskyrė moderatoriais","Administratorius {user0}, {user1} ir %n kitų dalyvių paskyrė moderatoriais","Administratorius {user0}, {user1} ir %n kitų dalyvių paskyrė moderatoriais"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} paskyrė {user0}, {user1} ir %n kitą dalyvį moderatoriais","{actor} paskyrė {user0}, {user1} ir %n kitus dalyvius moderatoriais","{actor} paskyrė {user0}, {user1} ir %n kitų dalyvių moderatoriais","{actor} paskyrė {user0}, {user1} ir %n kitų dalyvių moderatoriais"],
    "You demoted {user0} and {user1} from moderators" : "Jūs nušalinote {user0} ir {user1} iš moderatorių",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Jūs nušalinote {user0}, {user1} ir %n kitą dalyvį iš moderatorių","Jūs nušalinote {user0}, {user1} ir %n kitus dalyvius iš moderatorių","Jūs nušalinote {user0}, {user1} ir %n kitų dalyvių iš moderatorių","Jūs nušalinote {user0}, {user1} ir %n kitų dalyvių iš moderatorių"],
    "An administrator demoted you and {user0} from moderators" : "Administratorius nušalino jus ir {user0} iš moderatorių",
    "{actor} demoted you and {user0} from moderators" : "{actor} pašalino jus ir {user0} iš moderatorių",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Administratorius nušalino jus, {user0} ir %n kitą dalyvį iš moderatorių","Administratorius nušalino jus, {user0} ir %n kitus dalyvius iš moderatorių","Administratorius nušalino jus, {user0} ir %n kitų dalyvių iš moderatorių","Administratorius nušalino jus, {user0} ir %n kitų dalyvių iš moderatorių"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} pašalino jus, {user0} ir %n kitą dalyvį iš moderatorių","{actor} pašalino jus, {user0} ir %n kitus dalyvius iš moderatorių","{actor} pašalino jus, {user0} ir %n kitų dalyvių iš moderatorių","{actor} pašalino jus, {user0} ir %n kitų dalyvių iš moderatorių"],
    "An administrator demoted {user0} and {user1} from moderators" : "Administratorius nušalino {user0} ir {user1} iš moderatorių",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} pašalino {user0} ir {user1} iš moderatorių",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Administratorius nušalino {user0}, {user1} ir %n kitą dalyvį iš moderatorių","Administratorius nušalino {user0}, {user1} ir %n kitus dalyvius iš moderatorių","Administratorius nušalino {user0}, {user1} ir %n kitų dalyvių iš moderatorių","Administratorius nušalino {user0}, {user1} ir %n kitų dalyvių iš moderatorių"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} pašalino {user0}, {user1} ir %n kitą dalyvį iš moderatorių","{actor} pašalino {user0}, {user1} ir %n kitus dalyvius iš moderatorių","{actor} pašalino {user0}, {user1} ir %n kitų dalyvių iš moderatorių","{actor} pašalino {user0}, {user1} ir %n kitų dalyvių iš moderatorių"],
    "You:" : "Jūs:",
    "You: {lastMessage}" : "Jūs: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "Serveris buvo atnaujintas.",
    "(edited by you)" : "(jūsų redaguota)",
    "(edited by a deleted user)" : "(redagavo ištrintas vartotojas)",
    "(edited by {moderator})" : "(redagavo {moderator})",
    "The recording failed. Please contact your administrator." : "Įrašyti nepavyko. Susisiekite su administratoriumi.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Bandote prisijungti prie pokalbio, nors kituose languose ar kituose įrenginiuose jau vyksta sesija. Šiuo metu Nextcloud „Pokalbiai“ šios funkcijos nepalaiko. Ką norite daryti?",
    "Leave this page" : "Išeiti iš šio puslapio",
    "Join here" : "Prisijunkite čia",
    "Deck card has been posted to {conversation}" : "Darbų kortelė buvo išsiųsta į {conversation}",
    "An error occurred while posting deck card to conversation" : "Įkeliant kortelę į pokalbį įvyko klaida",
    "Post to a conversation" : "Paskelbti pokalbyje",
    "Post to conversation" : "Paskelbti pokalbyje",
    "Location has been posted to {conversation}" : "Vieta buvo paskelbta {conversation}",
    "An error occurred while posting location to conversation" : "Įrašant vietovę į pokalbį įvyko klaida",
    "Share to a conversation" : "Bendrinkite pokalbyje",
    "Share to conversation" : "Bendrinkite pokalbyje",
    "In conversation" : "Pokalbyje",
    "Search in conversation: {conversation}" : "Ieškoti pokalbyje: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Jūsų užklausos šiuo metu yra blokuojamos dėl aklosios jėgos atakų apsaugos.",
    "Error while clearing conversation history" : "Klaida išvalant pokalbio istoriją",
    "Error occurred while allowing guests" : "Klaida bandant leisti svečių prieigą",
    "Error occurred while disallowing guests" : "Klaida bandant uždrausti svečių prieigą",
    "Error occurred when restricting the conversation to moderator" : "Apribojant pokalbį moderatoriui įvyko klaida",
    "Error occurred when opening the conversation to everyone" : "Įvyko klaida atidarant kiekvienam pokalbį",
    "Conversation password has been saved" : "Pokalbio slaptažodis įrašytas",
    "Conversation password has been removed" : "Pokalbio slaptažodis pašalintas",
    "Error occurred while saving conversation password" : "Įrašant pokalbio slaptažodį įvyko klaida",
    "Call recording is starting." : "Pradedamas pokalbio įrašymas.",
    "Call recording stopped while starting." : "Pokalbio įrašymas buvo nutrauktas paleidimo metu.",
    "Call recording stopped. You will be notified once the recording is available." : "Skambučio įrašymas sustabdytas. Kai įrašas bus parengtas, jums bus pranešta.",
    "Conversation picture set" : "Pokalbio paveikslėlis nustatytas",
    "Conversation picture deleted" : "Pokalbio paveikslėlis ištrintas",
    "Could not delete the conversation picture" : "Nepavyko ištrinti pokalbio paveikslėlio",
    "Could not remove the automatic expiration" : "Nepavyko pašalinti automatinio galiojimo pabaigos",
    "Could not post message: {errorMessage}" : "Nepavyko paskelbti žinutės: {errorMessage}",
    "Participant is banned successfully" : "Dalyvis sėkmingai užblokuotas",
    "Error while banning the participant" : "Užblokuojant dalyvį įvyko klaida",
    "An error occurred while fetching the participants" : "Gaunant dalyvius, įvyko klaida",
    "Could not send invitation to {actorId}" : "Nepavyko išsiųsti kvietimo {actorId}",
    "Invitations sent" : "Pakvietimai išsiųsti",
    "Error occurred when sending invitations" : "Siunčiant kvietimus įvyko klaida",
    "Failed to join the conversation." : "Nepavyko prisijungti prie pokalbio.",
    "An error occurred while creating breakout rooms" : "Kuriant grupinio darbo kambarius įvyko klaida",
    "An error occurred while re-ordering the attendees" : "Perrikiuojant dalyvius įvyko klaida",
    "An error occurred while deleting breakout rooms" : "Šalinant grupinio darbo kambarius įvyko klaida",
    "An error occurred while starting breakout rooms" : "Pradedant grupinio darbo kambarius įvyko klaida",
    "An error occurred while stopping breakout rooms" : "Stabdant grupinio darbo kambarius įvyko klaida",
    "An error occurred while sending a message to the breakout rooms" : "Siunčiant pranešimą į grupinio darbo kambarius įvyko klaida",
    "An error occurred while requesting assistance" : "Prašant pagalbos įvyko klaida",
    "An error occurred while resetting the request for assistance" : "Atkuriant pagalbos užklausą įvyko klaida",
    "An error occurred while joining breakout room" : "Prisijungiant prie grupinio darbo kambario įvyko klaida",
    "Failed to rename the thread" : "Nepavyko pervadinti temos",
    "Error renaming tag" : "Klaida pervadinant žymę",
    "Error deleting tag" : "Klaida ištrinant žymę",
    "Error reordering tags" : "Klaida perrūšiuojant žymes",
    "Error fetching upcoming events" : "Klaida gaunant artėjančius renginius",
    "Error fetching upcoming reminders" : "Klaida gaunant būsimus priminimus",
    "An error occurred while accepting an invitation" : "Priimant kvietimą įvyko klaida",
    "An error occurred while rejecting an invitation" : "Atsisakant kvietimo įvyko klaida",
    "{guest} (guest)" : "{guest} (svečias)",
    "Poll draft has been saved" : "Apklausos projektas išsaugotas",
    "An error occurred while saving the draft" : "Išsaugant projektą įvyko klaida",
    "An error occurred while submitting your vote" : "Pateikiant balsą įvyko klaida",
    "An error occurred while ending the poll" : "Baigiant apklausą įvyko klaida",
    "An error occurred while deleting the poll draft" : "Šalinant apklausos projektą įvyko klaida",
    "Poll \"{name}\" was created by {user}. Click to vote" : "{user} sukūrė apklausą, pavadinimu „{name}“. Spustelėkite norėdami dalyvauti",
    "Failed to add reaction" : "Nepavyko pridėti reakcijos",
    "Failed to remove reaction" : "Nepavyko pašalinti reakcijos",
    "The server is in maintenance mode." : "Serveris yra techninės priežiūros režime.",
    "Federated server was updated." : "Federacinis serveris buvo atnaujintas.",
    "Error while uploading file \"{fileName}\"" : "Įkeliant failą „{fileName}“ įvyko klaida",
    "Not enough free space to upload file \"{fileName}\"" : "Nepakanka laisvos vietos failui „{fileName}“ įkelti",
    "You are not allowed to share files" : "Jums neleidžiama bendrinti failų",
    "Error while sharing file" : "Klaida bendrinant failą",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud „Pokalbiai“ nepalaiko naršyklės, kurią šiuo metu naudojate. Prašome naudoti naujausią „Mozilla Firefox“, „Microsoft Edge“, „Google Chrome“, „Opera“ arba „Apple Safari“ versiją.",
    "_%n hour_::_%n hours_" : ["%n valanda","%n valandos","%n valandų","%n valanda"],
    "_%n day_::_%n days_" : ["%n diena","%n dienos","%n dienų","%n diena"],
    "_%n week_::_%n weeks_" : ["%n savaitė","%n savaitės","%n savaičių","%n savaitė"],
    "_In %n hour_::_In %n hours_" : ["Po %n valandos","Po %n valandų","Po %n valandų","Po %n valandų"],
    "_%n minute _::_%n minutes_" : ["%n minutė","%n minutės","%n minučių","%n minučių"],
    "In {hours} and {minutes}" : "Po {hours} ir {minutes}",
    "_In %n minute_::_In %n minutes_" : ["Po %n minutės","Po %n minučių","Po %n minučių","Po %n minučių"],
    "Later today – {timeLocale}" : "Šiandien vėliau – {timeLocale}",
    "Set time for later today" : "Nustatyti laiką vėliau šiandien",
    "Tomorrow – {timeLocale}" : "Rytoj – {timeLocale}",
    "Set time for tomorrow" : "Nustatykite laiką rytojui",
    "This weekend – {timeLocale}" : "Šį savaitgalį – {timeLocale}",
    "Set time for this weekend" : "Nustatykite laiką šiam savaitgaliui",
    "Next week – {timeLocale}" : "Kitą savaitę – {timeLocale}",
    "Set time for next week" : "Nustatykite laiką kitai savaitei",
    "Message link copied to clipboard" : "Žinutės nuoroda nukopijuota į iškarpinę",
    "Conversation link copied to clipboard" : "Pokalbio nuoroda nukopijuota į iškarpinę",
    "The link could not be copied" : "Nepavyko nukopijuoti nuorodos",
    "Error while parsing a PROPFIND error" : "Klaida analizuojant „PROPFIND“ klaidą",
    "Sending signaling message has failed" : "Nepavyko išsiųsti signalinės žinutės.",
    "Lost connection to signaling server. Trying to reconnect." : "Prarastas ryšys su signaliniu serveriu. Bandoma prisijungti iš naujo.",
    "Lost connection to signaling server." : "Prarastas ryšys su signaliniu serveriu.",
    "Connecting is taking longer than expected …" : "Prisijungimas užtrunka ilgiau nei tikėtasi…",
    "Failed to connect. Retrying …" : "Nepavyko prisijungti. Bandoma dar kartą…",
    "Failed to connect. The signaling server may be set up incorrectly" : "Nepavyko prisijungti. Signalinis serveris gali būti nustatytas neteisingai.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "Sukonfigūruotą signalinį serverį reikia atnaujinti, kad jis būtų suderinamas su šia „Pokalbių“ versija. Susisiekite su administracija.",
    "Please restart the app." : "Prašome iš naujo paleisti programėlę.",
    "Please reload the page." : "Prašome įkelti puslapį iš naujo.",
    "Please try to restart the app." : "Prašome pabandyti iš naujo paleisti programėlę.",
    "Please try to reload the page." : "Pabandykite įkelti puslapį iš naujo.",
    "Do not disturb" : "Netrukdyti",
    "Away" : "Atsitraukęs",
    "Microphone {number}" : "Mikrofonas {number}",
    "Camera {number}" : "Kamera {number}",
    "Speaker {number}" : "Garsiakalbis {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Atrodo, kad kalbate su išjungtu mikrofonu, įjunkite savo garsą, jei norite, kad kiti jus girdėtų",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Nepavyko užmegzti ryšio su bent vienu dalyviu. Jūsų situacijai gali reikėti TURN serverio. Paprašykite administratoriaus jį nustatyti vadovaujantis šia {linkstart} dokumentacija {linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tai užtrunka ilgiau, nei tikėtasi. Ar medijos leidimai jau yra suteikti (arba atmesti)? Jeigu taip, tuomet paleiskite savo naršyklę iš naujo, nes garsas ir vaizdas patiria nesėkmę",
    "Access to microphone & camera is only possible with HTTPS" : "Prieiga prie mikrofono ir kameros yra įmanoma tik naudojant HTTPS",
    "Please move your setup to HTTPS" : "Perkelkite savo sąranką į HTTPS",
    "Access to microphone & camera was denied" : "Prieiga prie mikrofono ir kameros buvo uždrausta",
    "WebRTC is not supported in your browser" : "Jūsų naršyklėje WebRTC nėra palaikoma",
    "Please use a different browser like Firefox or Chrome" : "Naudokite kitą naršyklę, tokią kaip Firefox ar Chrome",
    "Error while accessing microphone & camera" : "Klaida gaunant prieigą prie mikrofono ir kameros",
    "%s Talk on your mobile devices" : "%s Pokalbiai jūsų mobiliuosiuose įrenginiuose",
    "Join conversations at any time, anywhere, on any device." : "Prisijunkite prie pokalbių bet kur, bet kada, bet kokiame įrenginyje.",
    "Android app" : "Android programėlė",
    "iOS app" : "iOS programėlė",
    "__language_name__" : "Lietuvių",
    "Webhook Demo" : "„Webhook“ demonstracija",
    "Call summary (%s)" : "Skambučio santrauka (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "Skambučių apibendrinimo botas po skambučio paskelbia apžvalgą, kurioje išvardijami visi dalyviai ir apibūdinamos užduotys",
    "Tasks" : "Užduotys",
    "Notes" : "Užrašai",
    "Reports" : "Ataskaitos",
    "Decisions" : "Sprendimai",
    "Agenda" : "Darbotvarkė",
    "Call summary" : "Skambučio santrauka",
    "Call summary - {title}" : "Skambučio santrauka - {title}",
    "Talk to %s" : "Kalbėti su %s",
    "Talk conversation for event" : "„Pokalbių“ pokalbis renginiui",
    "Client Push is installed, this improves the performance of desktop clients." : "Įdiegta kliento „Push“ funkcija, kuri padidina darbalaukio klientų našumą.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push} neįdiegtas, todėl naudojant darbalaukio klientus gali kilti našumo problemų.",
    "Next meeting" : "Kitas susitikimas",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Nustatykite susitikimą savo kalendoriuje. Kad „Pokalbių“ pokalbis būtų rodomas čia, reikia nurodyti jo vietą",
    "Join conversations from remote Nextcloud servers" : "Prisijunkite prie pokalbių iš nuotolinių Nextcloud serverių",
    "Your default media state has been saved" : "Jūsų numatytoji medijos būsena išsaugota",
    "Set reminder for later today" : "Nustatyti priminimą šiandien vėliau",
    "Set reminder for tomorrow" : "Nustatyti priminimą rytoj",
    "Set reminder for this weekend" : "Nustatyti priminimą šį savaitgalį",
    "Set reminder for next week" : "Nustatyti priminimą kitą savaitę",
    "Generate summary" : "Sukurti santrauką",
    "Open poll • You voted already" : "Atidaryti balsavimą • Jūs jau balsavote",
    "Open poll • Click to vote" : "Atidaryti apklausą • Spauskite, kad balsuotumėte",
    "Poll • Ended" : "Apklausa • Baigta",
    "Talk recording from {time} ({conversation})" : "„Pokalbiai“ įrašas iš {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Apklausos rezultatai • %n balsas","Apklausos rezultatai • %n balsai","Apklausos rezultatai • %n balsų","Apklausos rezultatai • %n balsų"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Atidaryti apklausą • %n balsas","Atidaryti apklausą • %n balsai","Atidaryti apklausą • %n balsų","Atidaryti apklausą • %n balsų"],
    "Submit vote" : "Pateikti balsavimą",
    "Your privacy setting has been saved" : "Jūsų privatumo nustatymas įrašytas",
    "Your personal setting has been saved" : "Jūsų asmeniniai nustatymai išsaugoti",
    "Failed to save sounds setting" : "Nepavyko išsaugoti garsų nustatymo",
    "Sounds setting saved" : "Garsų nustatymas išsaugotas",
    "Always shown if recording consent is required" : "Visada rodoma, jei reikalingas sutikimas įrašyti",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Nextcloud „Pokalbiai“ buvo atnaujintas, negalite pradėti skambučio ar prie jo prisijungti.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Prisijungėte prie pokalbio kitame lange arba įrenginyje. Šiuo metu Nextcloud „Pokalbiai“ to nepalaiko, todėl ši sesija buvo uždaryta.",
    "Nextcloud Talk was updated." : "Nextcloud „Pokalbiai“ atnaujinta.",
    "Nextcloud is in maintenance mode." : "Nextcloud veikia techninės priežiūros režimu.",
    "Nextcloud Talk Federation was updated." : "Atnaujinta Nextcloud „Pokalbiai“ federacija.",
    "Enable live translation" : "Įjungti vertimą realiuoju laiku",
    "_Open poll • %n vote • Your vote is anonymous_::_Open poll • %n votes • Your vote is anonymous_" : ["Atvira apklausa • %n balsas • Jūsų balsas anonimiškas","Atvira apklausa • %n balsai • Jūsų balsas anonimiškas","Atvira apklausa • %n balsų • Jūsų balsas anonimiškas","Atvira apklausa • %n balsų • Jūsų balsas anonimiškas"],
    "Open poll • You voted already • Your vote is anonymous" : "Atidaryti apklausą • Jūs jau balsavote • Jūsų balsas anonimiškas",
    "Open poll • Your vote is anonymous" : "Atvira apklausa • Jūsų balsas anonimiškas",
    "I picked list style" : "Pasirinkau sąrašo stilių",
    "Hey! Are you using Talk in list style or with message bubbles?" : "Ei! Ar naudojate „Pokalbius“ sąrašo stiliumi, ar su žinučių burbulais?"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
